@@ -1,10 +1,10 @@
 from __future__ import annotations
 
 import copy
-import os
-import unittest
+import re
 from glob import glob
 from shutil import which
+from unittest import TestCase
 
 import networkx as nx
 import networkx.algorithms.isomorphism as iso
@@ -43,17 +43,14 @@ __email__ = "mkhorton@lbl.gov"
 __status__ = "Beta"
 __date__ = "August 2017"
 
-module_dir = os.path.dirname(os.path.abspath(__file__))
-molecule_dir = f"{TEST_FILES_DIR}/molecules"
+TEST_DIR = f"{TEST_FILES_DIR}/analysis/graphs"
 
 
 class TestStructureGraph(PymatgenTest):
     def setUp(self):
-        self.maxDiff = None
-
         # trivial example, simple square lattice for testing
         structure = Structure(Lattice.tetragonal(5, 50), ["H"], [[0, 0, 0]])
-        self.square_sg = StructureGraph.with_empty_graph(structure, edge_weight_name="", edge_weight_units="")
+        self.square_sg = StructureGraph.from_empty_graph(structure, edge_weight_name="", edge_weight_units="")
         self.square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(1, 0, 0))
         self.square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(-1, 0, 0))
         self.square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(0, 1, 0))
@@ -63,7 +60,7 @@ class TestStructureGraph(PymatgenTest):
 
         # body-centered square lattice for testing
         structure = Structure(Lattice.tetragonal(5, 50), ["H", "He"], [[0, 0, 0], [0.5, 0.5, 0.5]])
-        self.bc_square_sg = StructureGraph.with_empty_graph(structure, edge_weight_name="", edge_weight_units="")
+        self.bc_square_sg = StructureGraph.from_empty_graph(structure, edge_weight_name="", edge_weight_units="")
         self.bc_square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(1, 0, 0))
         self.bc_square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(-1, 0, 0))
         self.bc_square_sg.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(0, 1, 0))
@@ -76,7 +73,7 @@ class TestStructureGraph(PymatgenTest):
         # body-centered square lattice for testing
         # directions reversed, should be equivalent to bc_square
         structure = Structure(Lattice.tetragonal(5, 50), ["H", "He"], [[0, 0, 0], [0.5, 0.5, 0.5]])
-        self.bc_square_sg_r = StructureGraph.with_empty_graph(structure, edge_weight_name="", edge_weight_units="")
+        self.bc_square_sg_r = StructureGraph.from_empty_graph(structure, edge_weight_name="", edge_weight_units="")
         self.bc_square_sg_r.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(1, 0, 0))
         self.bc_square_sg_r.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(-1, 0, 0))
         self.bc_square_sg_r.add_edge(0, 0, from_jimage=(0, 0, 0), to_jimage=(0, 1, 0))
@@ -88,10 +85,10 @@ class TestStructureGraph(PymatgenTest):
 
         # MoS2 example, structure graph obtained from critic2
         # (not ground state, from mp-1023924, single layer)
-        stdout_file = f"{TEST_FILES_DIR}/critic2/MoS2_critic2_stdout.txt"
+        stdout_file = f"{TEST_FILES_DIR}/command_line/critic2/MoS2_critic2_stdout.txt"
         with open(stdout_file) as txt_file:
             reference_stdout = txt_file.read()
-        self.structure = Structure.from_file(f"{TEST_FILES_DIR}/critic2/MoS2.cif")
+        self.structure = Structure.from_file(f"{TEST_FILES_DIR}/command_line/critic2/MoS2.cif")
         c2o = Critic2Analysis(self.structure, reference_stdout)
         self.mos2_sg = c2o.structure_graph(include_critical_points=False)
 
@@ -106,7 +103,7 @@ class TestStructureGraph(PymatgenTest):
     def test_inappropriate_construction(self):
         # Check inappropriate strategy
         with pytest.raises(ValueError, match="Chosen strategy is not designed for use with structures"):
-            StructureGraph.with_local_env_strategy(self.NiO, CovalentBondNN())
+            StructureGraph.from_local_env_strategy(self.NiO, CovalentBondNN())
 
     def test_properties(self):
         assert self.mos2_sg.name == "bonds"
@@ -134,7 +131,7 @@ class TestStructureGraph(PymatgenTest):
         ]
         nacl = Structure(nacl_lattice, ["Na", "Cl"], [[0, 0, 0], [0.5, 0.5, 0.5]])
 
-        nacl_graph = StructureGraph.with_local_env_strategy(nacl, CutOffDictNN({("Cl", "Cl"): 5.0}))
+        nacl_graph = StructureGraph.from_local_env_strategy(nacl, CutOffDictNN({("Cl", "Cl"): 5.0}))
 
         assert len(nacl_graph.get_connected_sites(1)) == 12
         assert len(nacl_graph.graph.get_edge_data(1, 1)) == 6
@@ -200,23 +197,23 @@ class TestStructureGraph(PymatgenTest):
         assert square_copy.graph.number_of_edges() == 3
 
     def test_substitute(self):
-        structure = Structure.from_file(f"{TEST_FILES_DIR}/Li2O.cif")
+        structure = Structure.from_file(f"{TEST_FILES_DIR}/cif/Li2O.cif")
         molecule = FunctionalGroups["methyl"]
 
         structure_copy = copy.deepcopy(structure)
         structure_copy_graph = copy.deepcopy(structure)
 
-        sg = StructureGraph.with_local_env_strategy(structure, MinimumDistanceNN())
-        sg_copy = copy.deepcopy(sg)
+        struct_graph = StructureGraph.from_local_env_strategy(structure, MinimumDistanceNN())
+        sg_copy = copy.deepcopy(struct_graph)
 
         # Ensure that strings and molecules lead to equivalent substitutions
-        sg.substitute_group(1, molecule, MinimumDistanceNN)
+        struct_graph.substitute_group(1, molecule, MinimumDistanceNN)
         sg_copy.substitute_group(1, "methyl", MinimumDistanceNN)
-        assert sg == sg_copy
+        assert struct_graph == sg_copy
 
         # Ensure that the underlying structure has been modified as expected
         structure_copy.substitute(1, "methyl")
-        assert structure_copy == sg.structure
+        assert structure_copy == struct_graph.structure
 
         # Test inclusion of graph dictionary
         graph_dict = {
@@ -225,16 +222,16 @@ class TestStructureGraph(PymatgenTest):
             (0, 3): {"weight": 0.5},
         }
 
-        sg_with_graph = StructureGraph.with_local_env_strategy(structure_copy_graph, MinimumDistanceNN())
+        sg_with_graph = StructureGraph.from_local_env_strategy(structure_copy_graph, MinimumDistanceNN())
         sg_with_graph.substitute_group(1, "methyl", MinimumDistanceNN, graph_dict=graph_dict)
         edge = sg_with_graph.graph.get_edge_data(11, 13)[0]
         assert edge["weight"] == 0.5
 
     def test_auto_image_detection(self):
-        sg = StructureGraph.with_empty_graph(self.structure)
-        sg.add_edge(0, 0)
+        struct_graph = StructureGraph.from_empty_graph(self.structure)
+        struct_graph.add_edge(0, 0)
 
-        assert len(list(sg.graph.edges(data=True))) == 3
+        assert len(list(struct_graph.graph.edges(data=True))) == 3
 
     def test_str(self):
         square_sg_str_ref = """Structure Graph
@@ -330,18 +327,21 @@ from    to  to_image
         for idx in mos2_sg_mul.structure.indices_from_symbol("Mo"):
             assert mos2_sg_mul.get_coordination_of_site(idx) == 6
 
-        mos2_sg_premul = StructureGraph.with_local_env_strategy(self.structure * (3, 3, 1), MinimumDistanceNN())
+        mos2_sg_premul = StructureGraph.from_local_env_strategy(self.structure * (3, 3, 1), MinimumDistanceNN())
         assert mos2_sg_mul == mos2_sg_premul
 
         # test 3D Structure
 
-        nio_sg = StructureGraph.with_local_env_strategy(self.NiO, MinimumDistanceNN())
-        nio_sg = nio_sg * 3
+        nio_struct_graph = StructureGraph.from_local_env_strategy(self.NiO, MinimumDistanceNN())
+        nio_struct_graph = nio_struct_graph * 3
 
-        for n in range(len(nio_sg)):
-            assert nio_sg.get_coordination_of_site(n) == 6
+        for n in range(len(nio_struct_graph)):
+            assert nio_struct_graph.get_coordination_of_site(n) == 6
 
-    @unittest.skipIf(pygraphviz is None or not (which("neato") and which("fdp")), "graphviz executables not present")
+    @pytest.mark.skipif(
+        pygraphviz is None or not (which("neato") and which("fdp")),
+        reason="graphviz executables not present",
+    )
     def test_draw(self):
         # draw MoS2 graph
         self.mos2_sg.draw_graph_to_file(f"{self.tmp_path}/MoS2_single.pdf", image_labels=True, hide_image_edges=False)
@@ -354,7 +354,7 @@ from    to  to_image
         mos2_sg_2.draw_graph_to_file(f"{self.tmp_path}/MoS2_twice_mul.pdf", algo="neato", hide_image_edges=True)
 
         # draw MoS2 graph that's generated from a pre-multiplied Structure
-        mos2_sg_premul = StructureGraph.with_local_env_strategy(self.structure * (3, 3, 1), MinimumDistanceNN())
+        mos2_sg_premul = StructureGraph.from_local_env_strategy(self.structure * (3, 3, 1), MinimumDistanceNN())
         mos2_sg_premul.draw_graph_to_file(f"{self.tmp_path}/MoS2_premul.pdf", algo="neato", hide_image_edges=True)
 
         # draw graph for a square lattice
@@ -389,25 +389,25 @@ from    to  to_image
         assert pdfs == expected_pdfs
 
     def test_as_from_dict(self):
-        d = self.mos2_sg.as_dict()
-        sg = StructureGraph.from_dict(d)
-        d2 = sg.as_dict()
-        assert d == d2
+        dct = self.mos2_sg.as_dict()
+        struct_graph = StructureGraph.from_dict(dct)
+        d2 = struct_graph.as_dict()
+        assert dct == d2
 
     def test_from_local_env_and_equality_and_diff(self):
-        nn = MinimumDistanceNN()
-        sg = StructureGraph.with_local_env_strategy(self.structure, nn)
+        min_dist_nn = MinimumDistanceNN()
+        struct_graph = StructureGraph.from_local_env_strategy(self.structure, min_dist_nn)
 
-        assert sg.graph.number_of_edges() == 6
+        assert struct_graph.graph.number_of_edges() == 6
 
         nn2 = MinimumOKeeffeNN()
-        sg2 = StructureGraph.with_local_env_strategy(self.structure, nn2)
+        sg2 = StructureGraph.from_local_env_strategy(self.structure, nn2)
 
-        assert sg == sg2
-        assert sg == self.mos2_sg
+        assert struct_graph == sg2
+        assert struct_graph == self.mos2_sg
 
         # TODO: find better test case where graphs are different
-        diff = sg.diff(sg2)
+        diff = struct_graph.diff(sg2)
         assert diff["dist"] == 0
 
         assert self.square_sg.get_coordination_of_site(0) == 2
@@ -422,23 +422,20 @@ from    to  to_image
 
         structure = Structure(Lattice.tetragonal(5.0, 50.0), ["H"], [[0, 0, 0]])
 
-        sg = StructureGraph.with_edges(structure, edges)
+        struct_graph = StructureGraph.from_edges(structure, edges)
 
-        assert sg == self.square_sg
+        assert struct_graph == self.square_sg
 
     def test_extract_molecules(self):
-        structure_file = os.path.join(
-            TEST_FILES_DIR,
-            "H6PbCI3N_mp-977013_symmetrized.cif",
-        )
+        structure_file = f"{TEST_FILES_DIR}/cif/H6PbCI3N_mp-977013_symmetrized.cif"
 
         struct = Structure.from_file(structure_file)
 
-        nn = MinimumDistanceNN()
-        sg = StructureGraph.with_local_env_strategy(struct, nn)
+        min_dist_nn = MinimumDistanceNN()
+        struct_graph = StructureGraph.from_local_env_strategy(struct, min_dist_nn)
 
-        molecules = sg.get_subgraphs_as_molecules()
-        assert molecules[0].composition.formula == "H3 C1"
+        molecules = struct_graph.get_subgraphs_as_molecules()
+        assert molecules[0].formula == "H3 C1"
         assert len(molecules) == 1
 
         molecules = self.mos2_sg.get_subgraphs_as_molecules()
@@ -471,11 +468,11 @@ from    to  to_image
             coords=[[0.005572, 0.994428, 0.151095]],
         )
 
-        nn = MinimumDistanceNN(cutoff=6, get_all_sites=True)
+        min_dist_nn = MinimumDistanceNN(cutoff=6, get_all_sites=True)
 
-        sg = StructureGraph.with_local_env_strategy(test_structure, nn)
+        struct_graph = StructureGraph.from_local_env_strategy(test_structure, min_dist_nn)
 
-        assert sg.graph.number_of_edges() == 3
+        assert struct_graph.graph.number_of_edges() == 3
 
     def test_sort(self):
         sg = copy.deepcopy(self.bc_square_sg_r)
@@ -488,11 +485,11 @@ from    to  to_image
         assert list(sg.graph.edges)[-2:] == [(1, 3, 0), (1, 2, 0)]
 
 
-class TestMoleculeGraph(unittest.TestCase):
+class TestMoleculeGraph(TestCase):
     def setUp(self):
-        cyclohexene_xyz = f"{TEST_FILES_DIR}/graphs/cyclohexene.xyz"
+        cyclohexene_xyz = f"{TEST_DIR}/cyclohexene.xyz"
         cyclohexene = Molecule.from_file(cyclohexene_xyz)
-        self.cyclohexene = MoleculeGraph.with_empty_graph(
+        self.cyclohexene = MoleculeGraph.from_empty_graph(
             cyclohexene, edge_weight_name="strength", edge_weight_units=""
         )
         self.cyclohexene.add_edge(0, 1, weight=1.0)
@@ -512,8 +509,8 @@ class TestMoleculeGraph(unittest.TestCase):
         self.cyclohexene.add_edge(5, 14, weight=1.0)
         self.cyclohexene.add_edge(5, 15, weight=1.0)
 
-        butadiene = Molecule.from_file(f"{TEST_FILES_DIR}/graphs/butadiene.xyz")
-        self.butadiene = MoleculeGraph.with_empty_graph(butadiene, edge_weight_name="strength", edge_weight_units="")
+        butadiene = Molecule.from_file(f"{TEST_DIR}/butadiene.xyz")
+        self.butadiene = MoleculeGraph.from_empty_graph(butadiene, edge_weight_name="strength", edge_weight_units="")
         self.butadiene.add_edge(0, 1, weight=2.0)
         self.butadiene.add_edge(1, 2, weight=1.0)
         self.butadiene.add_edge(2, 3, weight=2.0)
@@ -524,15 +521,15 @@ class TestMoleculeGraph(unittest.TestCase):
         self.butadiene.add_edge(3, 8, weight=1.0)
         self.butadiene.add_edge(3, 9, weight=1.0)
 
-        ethylene = Molecule.from_file(f"{TEST_FILES_DIR}/graphs/ethylene.xyz")
-        self.ethylene = MoleculeGraph.with_empty_graph(ethylene, edge_weight_name="strength", edge_weight_units="")
+        ethylene = Molecule.from_file(f"{TEST_DIR}/ethylene.xyz")
+        self.ethylene = MoleculeGraph.from_empty_graph(ethylene, edge_weight_name="strength", edge_weight_units="")
         self.ethylene.add_edge(0, 1, weight=2.0)
         self.ethylene.add_edge(0, 2, weight=1.0)
         self.ethylene.add_edge(0, 3, weight=1.0)
         self.ethylene.add_edge(1, 4, weight=1.0)
         self.ethylene.add_edge(1, 5, weight=1.0)
 
-        self.pc = Molecule.from_file(f"{TEST_FILES_DIR}/graphs/PC.xyz")
+        self.pc = Molecule.from_file(f"{TEST_DIR}/PC.xyz")
         self.pc_edges = [
             [5, 10],
             [5, 12],
@@ -548,9 +545,9 @@ class TestMoleculeGraph(unittest.TestCase):
             [6, 0],
             [6, 2],
         ]
-        self.pc_frag1 = Molecule.from_file(f"{TEST_FILES_DIR}/graphs/PC_frag1.xyz")
+        self.pc_frag1 = Molecule.from_file(f"{TEST_DIR}/PC_frag1.xyz")
         self.pc_frag1_edges = [[0, 2], [4, 2], [2, 1], [1, 3]]
-        self.tfsi = Molecule.from_file(f"{TEST_FILES_DIR}/graphs/TFSI.xyz")
+        self.tfsi = Molecule.from_file(f"{TEST_DIR}/TFSI.xyz")
         self.tfsi_edges = (
             [14, 1],
             [1, 4],
@@ -570,10 +567,10 @@ class TestMoleculeGraph(unittest.TestCase):
 
     def test_construction(self):
         pytest.importorskip("openbabel")
-        edges_frag = {(e[0], e[1]): {"weight": 1.0} for e in self.pc_frag1_edges}
-        mol_graph = MoleculeGraph.with_edges(self.pc_frag1, edges_frag)
-        # dumpfn(mol_graph.as_dict(), f"{module_dir}/pc_frag1_mg.json")
-        ref_mol_graph = loadfn(f"{module_dir}/pc_frag1_mg.json")
+        edges_frag = {(edge[0], edge[1]): {"weight": 1.0} for edge in self.pc_frag1_edges}
+        mol_graph = MoleculeGraph.from_edges(self.pc_frag1, edges_frag)
+        # dumpfn(mol_graph.as_dict(), f"{TEST_FILES_DIR}/analysis/bond_dissociation/pc_frag1_mg.json")
+        ref_mol_graph = loadfn(f"{TEST_FILES_DIR}/analysis/bond_dissociation/pc_frag1_mg.json")
         assert mol_graph == ref_mol_graph
         assert mol_graph.graph.adj == ref_mol_graph.graph.adj
         for node in mol_graph.graph.nodes:
@@ -581,10 +578,10 @@ class TestMoleculeGraph(unittest.TestCase):
             for ii in range(3):
                 assert mol_graph.graph.nodes[node]["coords"][ii] == ref_mol_graph.graph.nodes[node]["coords"][ii]
 
-        edges_pc = {(e[0], e[1]): {"weight": 1.0} for e in self.pc_edges}
-        mol_graph = MoleculeGraph.with_edges(self.pc, edges_pc)
-        # dumpfn(mol_graph.as_dict(), f"{module_dir}/pc_mg.json")
-        ref_mol_graph = loadfn(f"{module_dir}/pc_mg.json")
+        edges_pc = {(edge[0], edge[1]): {"weight": 1.0} for edge in self.pc_edges}
+        mol_graph = MoleculeGraph.from_edges(self.pc, edges_pc)
+        # dumpfn(mol_graph.as_dict(), f"{TEST_FILES_DIR}/analysis/bond_dissociation/pc_mg.json")
+        ref_mol_graph = loadfn(f"{TEST_FILES_DIR}/analysis/bond_dissociation/pc_mg.json")
         assert mol_graph == ref_mol_graph
         assert mol_graph.graph.adj == ref_mol_graph.graph.adj
         for node in mol_graph.graph:
@@ -592,18 +589,17 @@ class TestMoleculeGraph(unittest.TestCase):
             for ii in range(3):
                 assert mol_graph.graph.nodes[node]["coords"][ii] == ref_mol_graph.graph.nodes[node]["coords"][ii]
 
-        mol_graph_edges = MoleculeGraph.with_edges(self.pc, edges=edges_pc)
-        mol_graph_strat = MoleculeGraph.with_local_env_strategy(self.pc, OpenBabelNN())
+        mol_graph_edges = MoleculeGraph.from_edges(self.pc, edges=edges_pc)
+        mol_graph_strat = MoleculeGraph.from_local_env_strategy(self.pc, OpenBabelNN())
 
         assert mol_graph_edges.isomorphic_to(mol_graph_strat)
 
-        # Check inappropriate strategy
-        non_mol_strategy = VoronoiNN()
+        # Check error message on using inappropriate strategy for molecules
+        strategy = VoronoiNN()
         with pytest.raises(
-            ValueError,
-            match=f"strategy='{non_mol_strategy}' is not designed for use with molecules! Choose another strategy",
+            ValueError, match=re.escape(f"{strategy=} is not designed for use with molecules! Choose another strategy")
         ):
-            MoleculeGraph.with_local_env_strategy(self.pc, non_mol_strategy)
+            MoleculeGraph.from_local_env_strategy(self.pc, strategy)
 
     def test_properties(self):
         assert self.cyclohexene.name == "bonds"
@@ -633,7 +629,7 @@ class TestMoleculeGraph(unittest.TestCase):
     def test_coordination(self):
         molecule = Molecule(["C", "C"], [[0.0, 0.0, 0.0], [1.0, 0.0, 0.0]])
 
-        mg = MoleculeGraph.with_empty_graph(molecule)
+        mg = MoleculeGraph.from_empty_graph(molecule)
         assert mg.get_coordination_of_site(0) == 0
 
         assert self.cyclohexene.get_coordination_of_site(0) == 4
@@ -698,7 +694,7 @@ class TestMoleculeGraph(unittest.TestCase):
 
         just_he = Molecule(["He"], [[5, 5, 5]])
 
-        dis_mg = MoleculeGraph.with_empty_graph(disconnected)
+        dis_mg = MoleculeGraph.from_empty_graph(disconnected)
         dis_mg.add_edge(0, 1)
         dis_mg.add_edge(0, 2)
         dis_mg.add_edge(0, 3)
@@ -712,7 +708,7 @@ class TestMoleculeGraph(unittest.TestCase):
         assert fragments[1].molecule == just_he
         assert index_map == {0: 0, 1: 1, 2: 2, 3: 3, 4: 4, 5: 5}
 
-        con_mg = MoleculeGraph.with_empty_graph(no_he)
+        con_mg = MoleculeGraph.from_empty_graph(no_he)
         con_mg.add_edge(0, 1)
         con_mg.add_edge(0, 2)
         con_mg.add_edge(0, 3)
@@ -744,7 +740,7 @@ class TestMoleculeGraph(unittest.TestCase):
 
         # Test naive charge redistribution
         hydroxide = Molecule(["O", "H"], [[0, 0, 0], [0.5, 0.5, 0.5]], charge=-1)
-        oh_mg = MoleculeGraph.with_empty_graph(hydroxide)
+        oh_mg = MoleculeGraph.from_empty_graph(hydroxide)
 
         oh_mg.add_edge(0, 1)
 
@@ -767,14 +763,14 @@ class TestMoleculeGraph(unittest.TestCase):
             ],
         )
 
-        diff_spec_mg = MoleculeGraph.with_empty_graph(diff_species)
+        diff_spec_mg = MoleculeGraph.from_empty_graph(diff_species)
         diff_spec_mg.add_edge(0, 1)
         diff_spec_mg.add_edge(0, 2)
         diff_spec_mg.add_edge(0, 3)
         diff_spec_mg.add_edge(0, 4)
 
-        for i in range(1, 5):
-            bond = (0, i)
+        for idx in range(1, 5):
+            bond = (0, idx)
 
             split_mgs = diff_spec_mg.split_molecule_subgraphs([bond])
             for split_mg in split_mgs:
@@ -785,8 +781,8 @@ class TestMoleculeGraph(unittest.TestCase):
                     assert species[j] == str(atom.specie)
 
     def test_build_unique_fragments(self):
-        edges = {(e[0], e[1]): None for e in self.pc_edges}
-        mol_graph = MoleculeGraph.with_edges(self.pc, edges)
+        edges = {(edge[0], edge[1]): None for edge in self.pc_edges}
+        mol_graph = MoleculeGraph.from_edges(self.pc, edges)
         unique_fragment_dict = mol_graph.build_unique_fragments()
         unique_fragments = [fragment for key in unique_fragment_dict for fragment in unique_fragment_dict[key]]
         assert len(unique_fragments) == 295
@@ -820,7 +816,7 @@ class TestMoleculeGraph(unittest.TestCase):
         assert no_rings == []
 
     def test_isomorphic(self):
-        ethyl_xyz_path = f"{TEST_FILES_DIR}/graphs/ethylene.xyz"
+        ethyl_xyz_path = f"{TEST_DIR}/ethylene.xyz"
         ethylene = Molecule.from_file(ethyl_xyz_path)
         # swap carbons
         ethylene[0], ethylene[1] = ethylene[1], ethylene[0]
@@ -833,7 +829,7 @@ class TestMoleculeGraph(unittest.TestCase):
             (0, 5): {"weight": 1},
         }
 
-        ethylene_graph = MoleculeGraph.with_edges(ethylene, edges)
+        ethylene_graph = MoleculeGraph.from_edges(ethylene, edges)
         # If they are equal, they must also be isomorphic
         assert self.ethylene.isomorphic_to(ethylene_graph)
         assert not self.butadiene.isomorphic_to(self.ethylene)
@@ -841,11 +837,11 @@ class TestMoleculeGraph(unittest.TestCase):
         # check fix in https://github.com/materialsproject/pymatgen/pull/3221
         # by comparing graph with equal nodes but different edges
         edges[(1, 4)] = {"weight": 2}
-        assert not self.ethylene.isomorphic_to(MoleculeGraph.with_edges(ethylene, edges))
+        assert not self.ethylene.isomorphic_to(MoleculeGraph.from_edges(ethylene, edges))
 
     def test_substitute(self):
         molecule = FunctionalGroups["methyl"]
-        mol_graph = MoleculeGraph.with_edges(
+        mol_graph = MoleculeGraph.from_edges(
             molecule,
             {(0, 1): {"weight": 1}, (0, 2): {"weight": 1}, (0, 3): {"weight": 1}},
         )
@@ -891,10 +887,10 @@ class TestMoleculeGraph(unittest.TestCase):
         assert eth_copy_repl.get_coordination_of_site(5) == 3
 
     def test_as_from_dict(self):
-        d = self.cyclohexene.as_dict()
-        mg = MoleculeGraph.from_dict(d)
-        d2 = mg.as_dict()
-        assert str(d) == str(d2)
+        dct = self.cyclohexene.as_dict()
+        mg = MoleculeGraph.from_dict(dct)
+        dct2 = mg.as_dict()
+        assert str(dct) == str(dct2)
 
     def test_sort(self):
         sg = copy.deepcopy(self.ethylene)
