@@ -12,7 +12,7 @@ from pymatgen.core.operations import SymmOp
 from pymatgen.util.testing import PymatgenTest
 
 
-class LatticeTestCase(PymatgenTest):
+class TestLattice(PymatgenTest):
     def setUp(self):
         self.lattice = Lattice.cubic(10.0)
         self.cubic = self.lattice
@@ -24,19 +24,27 @@ class LatticeTestCase(PymatgenTest):
 
         self.cubic_partial_pbc = Lattice.cubic(10.0, pbc=(True, True, False))
 
-        family_names = [
-            "cubic",
-            "tetragonal",
-            "orthorhombic",
-            "monoclinic",
-            "hexagonal",
-            "rhombohedral",
-        ]
-
         self.families = {}
-        for name in family_names:
+        for name in ("cubic", "tetragonal", "orthorhombic", "monoclinic", "hexagonal", "rhombohedral"):
             self.families[name] = getattr(self, name)
 
+    def test_init(self):
+        len_a = 9.026
+        lattice = Lattice.cubic(len_a)
+        assert lattice is not None, "Initialization from new_cubic failed"
+        assert_array_equal(lattice.pbc, (True, True, True))
+        assert hash(lattice) == -6887896986157825384
+
+        lattice2 = Lattice(np.eye(3) * len_a)
+        for ii in range(3):
+            for jj in range(3):
+                assert lattice.matrix[ii][jj] == lattice2.matrix[ii][jj], "Inconsistent matrix from two inits!"
+        assert_array_equal(self.cubic_partial_pbc.pbc, (True, True, False))
+
+        for bad_pbc in [(True, True), (True, True, True, True), (True, True, 2)]:
+            with pytest.raises(ValueError, match="pbc must be a tuple of three True/False values, got"):
+                Lattice(np.eye(3), pbc=bad_pbc)
+
     def test_equal(self):
         assert self.cubic == self.cubic
         assert self.cubic == self.lattice
@@ -45,7 +53,7 @@ class LatticeTestCase(PymatgenTest):
                 assert (name1 == name2) == (latt1 == latt2)
 
         # ensure partial periodic boundaries is unequal to all full periodic boundaries
-        assert not any(self.cubic_partial_pbc == x for x in self.families.values())
+        assert not any(self.cubic_partial_pbc == family for family in self.families.values())
 
     def test_format(self):
         assert (
@@ -57,17 +65,6 @@ class LatticeTestCase(PymatgenTest):
         assert format(self.lattice, ".3f") == lattice_str
         assert format(self.lattice, ".1fp") == "{10.0, 10.0, 10.0, 90.0, 90.0, 90.0}"
 
-    def test_init(self):
-        a = 9.026
-        lattice = Lattice.cubic(a)
-        assert lattice is not None, "Initialization from new_cubic failed"
-        assert_array_equal(lattice.pbc, (True, True, True))
-        lattice2 = Lattice([[a, 0, 0], [0, a, 0], [0, 0, a]])
-        for ii in range(3):
-            for jj in range(3):
-                assert lattice.matrix[ii][jj] == lattice2.matrix[ii][jj], "Inconsistent matrix from two inits!"
-        assert_array_equal(self.cubic_partial_pbc.pbc, (True, True, False))
-
     def test_copy(self):
         cubic_copy = self.cubic.copy()
         assert cubic_copy == self.cubic
@@ -85,8 +82,8 @@ class LatticeTestCase(PymatgenTest):
         # Random testing that get_cart and get_frac coords reverses each other.
         rand_coord = np.random.random_sample(3)
         coord = self.tetragonal.get_cartesian_coords(rand_coord)
-        fcoord = self.tetragonal.get_fractional_coords(coord)
-        assert_allclose(fcoord, rand_coord)
+        frac_coord = self.tetragonal.get_fractional_coords(coord)
+        assert_allclose(frac_coord, rand_coord)
 
     def test_get_vector_along_lattice_directions(self):
         lattice_mat = np.array([[0.5, 0.0, 0.0], [0.5, np.sqrt(3) / 2.0, 0.0], [0.0, 0.0, 1.0]])
@@ -110,12 +107,12 @@ class LatticeTestCase(PymatgenTest):
     def test_d_hkl(self):
         cubic_copy = self.cubic.copy()
         hkl = (1, 2, 3)
-        dhkl = ((hkl[0] ** 2 + hkl[1] ** 2 + hkl[2] ** 2) / (cubic_copy.a**2)) ** (-1 / 2)
-        assert dhkl == cubic_copy.d_hkl(hkl)
+        d_hkl = ((hkl[0] ** 2 + hkl[1] ** 2 + hkl[2] ** 2) / (cubic_copy.a**2)) ** (-1 / 2)
+        assert d_hkl == cubic_copy.d_hkl(hkl)
 
     def test_reciprocal_lattice(self):
-        recip_latt = self.lattice.reciprocal_lattice
-        assert_allclose(recip_latt.matrix, 0.628319 * np.eye(3), atol=1e-6)
+        recip_lattice = self.lattice.reciprocal_lattice
+        assert_allclose(recip_lattice.matrix, 0.628319 * np.eye(3), atol=1e-6)
         assert_allclose(
             self.tetragonal.reciprocal_lattice.matrix,
             [[0.628319, 0.0, 0.0], [0.0, 0.628319, 0], [0.0, 0.0, 0.3141590]],
@@ -123,8 +120,8 @@ class LatticeTestCase(PymatgenTest):
         )
 
         # Test the crystallographic version.
-        recip_latt_xtal = self.lattice.reciprocal_lattice_crystallographic
-        assert_allclose(recip_latt.matrix, recip_latt_xtal.matrix * 2 * np.pi, 5)
+        recip_lattice_crystallographic = self.lattice.reciprocal_lattice_crystallographic
+        assert_allclose(recip_lattice.matrix, recip_lattice_crystallographic.matrix * 2 * np.pi, 5)
 
     def test_static_methods(self):
         expected_lengths = [3.840198, 3.84019885, 3.8401976]
@@ -180,9 +177,9 @@ class LatticeTestCase(PymatgenTest):
         assert np.linalg.det(np.linalg.solve(expected.matrix, reduced_latt.matrix)) == approx(1)
         assert_allclose(sorted(reduced_latt.abc), sorted(expected.abc))
         assert reduced_latt.volume == approx(lattice.volume)
-        latt = [7.164750, 2.481942, 0.000000, -4.298850, 2.481942, 0.000000, 0.000000, 0.000000, 14.253000]
+        lattice = [7.164750, 2.481942, 0.000000, -4.298850, 2.481942, 0.000000, 0.000000, 0.000000, 14.253000]
         expected = Lattice([-4.298850, 2.481942, 0.000000, 2.865900, 4.963884, 0.000000, 0.000000, 0.000000, 14.253000])
-        reduced_latt = Lattice(latt).get_lll_reduced_lattice()
+        reduced_latt = Lattice(lattice).get_lll_reduced_lattice()
         assert np.linalg.det(np.linalg.solve(expected.matrix, reduced_latt.matrix)) == approx(1)
         assert_allclose(sorted(reduced_latt.abc), sorted(expected.abc))
 
@@ -201,63 +198,72 @@ class LatticeTestCase(PymatgenTest):
             assert reduced_random_latt.volume == approx(random_latt.volume)
 
     def test_get_niggli_reduced_lattice(self):
-        latt = Lattice.from_parameters(3, 5.196, 2, 103 + 55 / 60, 109 + 28 / 60, 134 + 53 / 60)
-        reduced_cell = latt.get_niggli_reduced_lattice()
+        lattice = Lattice.from_parameters(3, 5.196, 2, 103 + 55 / 60, 109 + 28 / 60, 134 + 53 / 60)
+        reduced_cell = lattice.get_niggli_reduced_lattice()
         abc = reduced_cell.lengths
         angles = reduced_cell.angles
         assert abc == approx([2, 3, 3], abs=1e-3)
         assert angles == approx([116.382855225, 94.769790287999996, 109.466666667])
 
-        mat = [[5.0, 0, 0], [0, 5.0, 0], [5.0, 0, 5.0]]
-        latt = Lattice(np.dot([[1, 1, 1], [1, 1, 0], [0, 1, 1]], mat))
-        reduced_cell = latt.get_niggli_reduced_lattice()
+        lattice = Lattice(np.dot([[1, 1, 1], [1, 1, 0], [0, 1, 1]], 5 * np.eye(3)))
+        reduced_cell = lattice.get_niggli_reduced_lattice()
         assert reduced_cell.lengths == approx([5, 5, 5])
         assert reduced_cell.angles == approx([90, 90, 90])
 
-        latt = Lattice([1.432950, 0.827314, 4.751000, -1.432950, 0.827314, 4.751000, 0.0, -1.654628, 4.751000])
+        lattice = Lattice([1.432950, 0.827314, 4.751000, -1.432950, 0.827314, 4.751000, 0.0, -1.654628, 4.751000])
         expected = [
             [-1.43295, -2.481942, 0.0],
             [-2.8659, 0.0, 0.0],
             [-1.43295, -0.827314, -4.751],
         ]
-        assert_allclose(latt.get_niggli_reduced_lattice().matrix, expected)
+        assert_allclose(lattice.get_niggli_reduced_lattice().matrix, expected)
 
-        latt = Lattice.from_parameters(7.365450, 6.199506, 5.353878, 75.542191, 81.181757, 156.396627)
+        lattice = Lattice.from_parameters(7.365450, 6.199506, 5.353878, 75.542191, 81.181757, 156.396627)
         expected = [
             [2.578932, 0.826965, 0.000000],
             [-0.831059, 2.067413, 1.547813],
             [-0.458407, -2.480895, 1.129126],
         ]
-        assert_allclose(latt.get_niggli_reduced_lattice().matrix, np.array(expected), atol=1e-5)
+        assert_allclose(lattice.get_niggli_reduced_lattice().matrix, expected, atol=1e-5)
+
+        lattice = Lattice([-0.2590, 1.1866, -0.1235, 2.2166, 1.0065, 0.7327, 1.1439, -0.4686, -0.0229])
+        expected = [
+            [-0.8849, -0.718, 0.1464],
+            [0.1878, 0.7571, 0.902],
+            [-0.4468, 0.4295, -1.0255],
+        ]
+        assert_allclose(lattice.get_niggli_reduced_lattice().matrix, expected, atol=1e-5)
 
     def test_find_mapping(self):
-        m = np.array([[0.1, 0.2, 0.3], [-0.1, 0.2, 0.7], [0.6, 0.9, 0.2]])
-        latt = Lattice(m)
+        matrix = [[0.1, 0.2, 0.3], [-0.1, 0.2, 0.7], [0.6, 0.9, 0.2]]
+        lattice = Lattice(matrix)
 
         op = SymmOp.from_origin_axis_angle([0, 0, 0], [2, 3, 3], 35)
         rot = op.rotation_matrix
         scale = np.array([[1, 1, 0], [0, 1, 0], [0, 0, 1]])
 
-        latt2 = Lattice(np.dot(rot, np.dot(scale, m).T).T)
-        (aligned_out, rot_out, scale_out) = latt2.find_mapping(latt)
+        latt2 = Lattice(np.dot(rot, np.dot(scale, matrix).T).T)
+        mapping = latt2.find_mapping(lattice)
+        assert isinstance(mapping, tuple)
+        aligned_out, rot_out, scale_out = mapping
         assert abs(np.linalg.det(rot)) == approx(1)
 
-        rotated = SymmOp.from_rotation_and_translation(rot_out).operate_multi(latt.matrix)
+        rotated = SymmOp.from_rotation_and_translation(rot_out).operate_multi(lattice.matrix)
 
         assert_allclose(rotated, aligned_out.matrix)
         assert_allclose(np.dot(scale_out, latt2.matrix), aligned_out.matrix)
-        assert_allclose(aligned_out.parameters, latt.parameters)
+        assert_allclose(aligned_out.parameters, lattice.parameters)
         assert not np.allclose(aligned_out.parameters, latt2.parameters)
 
     def test_find_all_mappings(self):
-        m = np.array([[0.1, 0.2, 0.3], [-0.1, 0.2, 0.7], [0.6, 0.9, 0.2]])
-        lattice = Lattice(m)
+        matrix = [[0.1, 0.2, 0.3], [-0.1, 0.2, 0.7], [0.6, 0.9, 0.2]]
+        lattice = Lattice(matrix)
 
         op = SymmOp.from_origin_axis_angle([0, 0, 0], [2, -1, 3], 40)
         rot = op.rotation_matrix
         scale = np.array([[0, 2, 0], [1, 1, 0], [0, 0, 1]])
 
-        latt2 = Lattice(np.dot(rot, np.dot(scale, m).T).T)
+        latt2 = Lattice(np.dot(rot, np.dot(scale, matrix).T).T)
 
         for aligned_out, rot_out, scale_out in lattice.find_all_mappings(latt2):
             assert_allclose(np.inner(latt2.matrix, rot_out), aligned_out.matrix, atol=1e-12)
@@ -274,15 +280,15 @@ class LatticeTestCase(PymatgenTest):
             assert isinstance(latt, Lattice)
 
     def test_mapping_symmetry(self):
-        latt = Lattice.cubic(1)
+        lattice = Lattice.cubic(1)
         l2 = Lattice.orthorhombic(1.1001, 1, 1)
-        assert latt.find_mapping(l2, ltol=0.1) == l2.find_mapping(latt, ltol=0.1)
-        assert l2.find_mapping(latt, ltol=0.1) is None
+        assert lattice.find_mapping(l2, ltol=0.1) == l2.find_mapping(lattice, ltol=0.1)
+        assert l2.find_mapping(lattice, ltol=0.1) is None
         l2 = Lattice.orthorhombic(1.0999, 1, 1)
-        mapping = l2.find_mapping(latt, ltol=0.1)
+        mapping = l2.find_mapping(lattice, ltol=0.1)
         assert isinstance(mapping, tuple)
         assert len(mapping) == 3
-        assert latt.find_mapping(l2, ltol=0.1) is not None
+        assert lattice.find_mapping(l2, ltol=0.1) is not None
 
     def test_as_from_dict(self):
         dct = self.tetragonal.as_dict()
@@ -315,13 +321,13 @@ class LatticeTestCase(PymatgenTest):
             assert_allclose(new_lattice.angles, lattice.angles)
 
     def test_get_wigner_seitz_cell(self):
-        ws_cell = Lattice([[10, 0, 0], [0, 5, 0], [0, 0, 1]]).get_wigner_seitz_cell()
+        ws_cell = Lattice(np.diag([10, 5, 1])).get_wigner_seitz_cell()
         assert len(ws_cell) == 6
         for vec in ws_cell[3]:
             assert [abs(i) for i in vec] == [5.0, 2.5, 0.5]
 
     def test_dot_and_norm(self):
-        frac_basis = [[1, 0, 0], [0, 1, 0], [0, 0, 1]]
+        frac_basis = np.eye(3)
 
         for lattice in self.families.values():
             assert_allclose(lattice.norm(lattice.matrix, frac_coords=False), lattice.abc, 5)
@@ -330,7 +336,7 @@ class LatticeTestCase(PymatgenTest):
                 length = lattice.norm(vec)
                 assert_allclose(length[0], lattice.abc[i], 5)
                 # We always get a ndarray.
-                assert hasattr(length, "shape")
+                assert length.shape == (1,)
 
         # Passing complex arrays should raise TypeError
         with pytest.raises(TypeError, match="Complex array"):
@@ -346,28 +352,42 @@ class LatticeTestCase(PymatgenTest):
 
     def test_get_points_in_sphere(self):
         # This is a non-niggli representation of a cubic lattice
-        latt = Lattice([[1, 5, 0], [0, 1, 0], [5, 0, 1]])
+        lattice = Lattice([[1, 5, 0], [0, 1, 0], [5, 0, 1]])
         # evenly spaced points array between 0 and 1
-        pts = np.array(list(itertools.product(range(5), repeat=3))) / 5
-        pts = latt.get_fractional_coords(pts)
+        points = np.array(list(itertools.product(range(5), repeat=3))) / 5
+        points = lattice.get_fractional_coords(points)
 
         # Test getting neighbors within 1 neighbor distance of the origin
-        fcoords, dists, inds, images = latt.get_points_in_sphere(pts, [0, 0, 0], 0.20001, zip_results=False)
-        assert len(fcoords) == 7  # There are 7 neighbors
+        frac_coords, dists, indices, images = lattice.get_points_in_sphere(
+            points, [0, 0, 0], 0.20001, zip_results=False
+        )
+        assert len(frac_coords) == 7  # There are 7 neighbors
         assert np.isclose(dists, 0.2).sum() == 6  # 6 are at 0.2
         assert np.isclose(dists, 0).sum() == 1  # 1 is at 0
-        assert len(set(inds)) == 7  # They have unique indices
-        assert_array_equal(images[np.isclose(dists, 0)], [[0, 0, 0]])
+        assert len(set(indices)) == 7  # They have unique indices
+        assert images[np.isclose(dists, 0)].tolist() == [[0, 0, 0]]
 
         # More complicated case, using the zip output
-        result = latt.get_points_in_sphere(pts, [0.5, 0.5, 0.5], 1.0001)
+        result = lattice.get_points_in_sphere(points, [0.5, 0.5, 0.5], 1.0001)
+        assert isinstance(result, tuple)
         assert len(result) == 552
-        assert len(result[0]) == 4  # coords, dists, ind, supercell
+        assert len(result[0]) == 4  # coords, dists, indices, supercell
 
         # test pbc
         latt_pbc = Lattice([[1, 5, 0], [0, 1, 0], [5, 0, 1]], pbc=(True, True, False))
-        fcoords, dists, inds, images = latt_pbc.get_points_in_sphere(pts, [0, 0, 0], 0.20001, zip_results=False)
-        assert len(fcoords) == 6
+        frac_coords, dists, indices, images = latt_pbc.get_points_in_sphere(
+            points, [0, 0, 0], 0.20001, zip_results=False
+        )
+        assert len(frac_coords) == 6
+
+        # ensure consistent return type if zip_results=False and no points in sphere are found
+        # https://github.com/materialsproject/pymatgen/issues/3794
+        result = lattice.get_points_in_sphere(points, [0.5, 0.5, 0.5], 0.0001, zip_results=False)
+        assert isinstance(result, tuple)
+        assert len(result) == 4
+        assert all(len(arr) == 0 for arr in result)
+        types = {*map(type, result)}
+        assert types == {np.ndarray}, f"Expected only np.ndarray, got {types}"
 
     def test_get_all_distances(self):
         fcoords = np.array(
@@ -431,8 +451,8 @@ class LatticeTestCase(PymatgenTest):
 
     def test_get_distance_and_image_strict(self):
         for _ in range(10):
-            lengths = [np.random.randint(1, 100) for i in range(3)]
-            lattice = [np.random.rand(3) * lengths[i] for i in range(3)]
+            lengths = np.random.randint(1, 100, 3)
+            lattice = np.random.rand(3, 3) * lengths
             lattice = Lattice(lattice)
 
             f1 = np.random.rand(3)
@@ -477,32 +497,32 @@ class LatticeTestCase(PymatgenTest):
 
     def test_get_miller_index_from_sites(self):
         # test on a cubic system
-        m = Lattice.cubic(1)
+        cubic = Lattice.cubic(1)
         s1 = np.array([0.5, -1.5, 3])
         s2 = np.array([0.5, 3.0, -1.5])
         s3 = np.array([2.5, 1.5, -4.0])
-        assert m.get_miller_index_from_coords([s1, s2, s3]) == (2, 1, 1)
+        assert cubic.get_miller_index_from_coords([s1, s2, s3]) == (2, 1, 1)
 
         # test on a hexagonal system
-        m = Lattice([[2.319, -4.01662582, 0.0], [2.319, 4.01662582, 0.0], [0.0, 0.0, 7.252]])
+        hexagonal = Lattice([[2.319, -4.01662582, 0.0], [2.319, 4.01662582, 0.0], [0.0, 0.0, 7.252]])
 
         s1 = np.array([2.319, 1.33887527, 6.3455])
         s2 = np.array([1.1595, 0.66943764, 4.5325])
         s3 = np.array([1.1595, 0.66943764, 0.9065])
-        hkl = m.get_miller_index_from_coords([s1, s2, s3])
+        hkl = hexagonal.get_miller_index_from_coords([s1, s2, s3])
         assert hkl == (2, -1, 0)
 
         # test for previous failing structure
-        m = Lattice([10, 0, 0, 0, 10, 0, 0, 0, 10])
+        cubic_from_flat = Lattice([10, 0, 0, 0, 10, 0, 0, 0, 10])
         sites = [[0.5, 0.8, 0.8], [0.5, 0.4, 0.2], [0.5, 0.3, 0.7]]
 
-        hkl = m.get_miller_index_from_coords(sites, coords_are_cartesian=False)
+        hkl = cubic_from_flat.get_miller_index_from_coords(sites, coords_are_cartesian=False)
         assert hkl == (1, 0, 0)
 
         # test for more than 3 sites
         sites = [[0.5, 0.8, 0.8], [0.5, 0.4, 0.2], [0.5, 0.3, 0.7], [0.5, 0.1, 0.2]]
 
-        hkl = m.get_miller_index_from_coords(sites, coords_are_cartesian=False)
+        hkl = cubic_from_flat.get_miller_index_from_coords(sites, coords_are_cartesian=False)
         assert hkl == (1, 0, 0)
 
     def test_points_in_spheres(self):
@@ -555,17 +575,17 @@ class LatticeTestCase(PymatgenTest):
         a1 = 10
         assert_allclose(
             Lattice.cubic(a1).selling_vector.round(4),
-            np.array([0, 0, 0, -(a1**2), -(a1**2), -(a1**2)]),
+            [0, 0, 0, -(a1**2), -(a1**2), -(a1**2)],
         )
         a2, c2 = 5, 8
         assert_allclose(
             Lattice.tetragonal(a2, c2).selling_vector.round(4),
-            np.array([0, 0, 0, -(a2**2), -(a2**2), -(c2**2)]),
+            [0, 0, 0, -(a2**2), -(a2**2), -(c2**2)],
         )
         a3, b3, c3 = 4, 6, 7
         assert_allclose(
             Lattice.orthorhombic(a3, b3, c3).selling_vector.round(4),
-            np.array([0, 0, 0, -(a3**2), -(b3**2), -(c3**2)]),
+            [0, 0, 0, -(a3**2), -(b3**2), -(c3**2)],
         )
 
     def test_is_3d_periodic(self):
