@@ -2,19 +2,22 @@ from __future__ import annotations
 
 import math
 import pickle
-import unittest
+import re
 from copy import deepcopy
+from enum import Enum
 
 import numpy as np
 import pytest
 from pytest import approx
 
 from pymatgen.core import DummySpecies, Element, Species, get_el_sp
-from pymatgen.core.periodic_table import ElementBase
+from pymatgen.core.periodic_table import ElementBase, ElementType
+from pymatgen.core.units import Ha_to_eV
+from pymatgen.io.core import ParseError
 from pymatgen.util.testing import PymatgenTest
 
 
-class ElementTestCase(PymatgenTest):
+class TestElement(PymatgenTest):
     def test_init(self):
         assert Element("Fe").symbol == "Fe"
 
@@ -211,8 +214,8 @@ class ElementTestCase(PymatgenTest):
             ],  # f3
             "Ne": [["1S0"]],
         }
-        for k, v in cases.items():
-            assert Element(k).term_symbols == v
+        for key, val in cases.items():
+            assert Element(key).term_symbols == val
 
     def test_ground_state_term_symbol(self):
         cases = {
@@ -222,87 +225,100 @@ class ElementTestCase(PymatgenTest):
             "Ti": "3F2.0",  # d2
             "Pr": "4I4.5",
         }  # f3
-        for k, v in cases.items():
-            assert Element(k).ground_state_term_symbol == v
+        for key, val in cases.items():
+            assert Element(key).ground_state_term_symbol == val
 
     def test_attributes(self):
-        is_true = {
-            ("Xe", "Kr"): "is_noble_gas",
-            ("Fe", "Ni"): "is_transition_metal",
-            ("Li", "Cs"): "is_alkali",
-            ("Ca", "Mg"): "is_alkaline",
-            ("F", "Br", "I"): "is_halogen",
-            ("La",): "is_lanthanoid",
-            ("U", "Pu"): "is_actinoid",
-            ("Si", "Ge"): "is_metalloid",
-            ("O", "Te"): "is_chalcogen",
+        bool_attrs = {
+            ("Xe", "Kr"): ("is_noble_gas", True),
+            ("H", "Cl"): ("is_noble_gas", False),
+            ("Fe", "Ni"): ("is_transition_metal", True),
+            ("Li", "Cs"): ("is_alkali", True),
+            ("Ca", "Mg"): ("is_alkaline", True),
+            ("F", "Br", "I"): ("is_halogen", True),
+            ("La", "Ce", "Lu"): ("is_lanthanoid", True),
+            ("U", "Pu"): ("is_actinoid", True),
+            ("Si", "Ge"): ("is_metalloid", True),
+            ("O", "Te"): ("is_chalcogen", True),
+            ("N", "Sb", "Ta"): ("is_chalcogen", False),
+            ("Tc", "Po"): ("is_radioactive", True),
+            ("H", "Li", "Bi"): ("is_radioactive", False),
         }
 
-        for key, v in is_true.items():
-            for sym in key:
-                assert getattr(Element(sym), v), f"{sym=} is false"
+        for elements, (attr, expected) in bool_attrs.items():
+            for elem in elements:
+                assert getattr(Element(elem), attr) is expected, f"{elem=} {attr=}, {expected=}"
 
-        keys = [
-            "mendeleev_no",
+        keys = (
             "atomic_mass",
-            "electronic_structure",
+            "atomic_orbitals",
+            "atomic_orbitals_eV",
             "atomic_radius",
-            "min_oxidation_state",
-            "max_oxidation_state",
+            "average_anionic_radius",
+            "average_cationic_radius",
+            "average_ionic_radius",
+            "boiling_point",
+            "brinell_hardness",
+            "bulk_modulus",
+            "coefficient_of_linear_thermal_expansion",
+            "common_oxidation_states",
+            "critical_temperature",
+            "density_of_solid",
             "electrical_resistivity",
-            "velocity_of_sound",
+            "electronic_structure",
+            "ground_level",
+            "ionic_radii",
+            "ionization_energies",
+            "iupac_ordering",
+            "liquid_range",
+            "long_name",
+            "max_oxidation_state",
+            "melting_point",
+            "mendeleev_no",
+            "metallic_radius",
+            "min_oxidation_state",
+            "mineral_hardness",
+            "molar_volume",
+            "oxidation_states",
+            "poissons_ratio",
             "reflectivity",
             "refractive_index",
-            "poissons_ratio",
-            "molar_volume",
-            "thermal_conductivity",
-            "melting_point",
-            "boiling_point",
-            "liquid_range",
-            "critical_temperature",
-            "superconduction_temperature",
-            "bulk_modulus",
-            "youngs_modulus",
-            "brinell_hardness",
             "rigidity_modulus",
-            "mineral_hardness",
+            "superconduction_temperature",
+            "thermal_conductivity",
+            "velocity_of_sound",
             "vickers_hardness",
-            "density_of_solid",
-            "atomic_orbitals",
-            "coefficient_of_linear_thermal_expansion",
-            "oxidation_states",
-            "common_oxidation_states",
-            "average_ionic_radius",
-            "average_cationic_radius",
-            "average_anionic_radius",
-            "ionic_radii",
-            "long_name",
-            "metallic_radius",
-            "iupac_ordering",
-            "ground_level",
-            "ionization_energies",
-        ]
+            "youngs_modulus",
+        )
 
         # Test all elements up to Uranium
         for idx in range(1, 104):
             el = Element.from_Z(idx)
-            for key in keys:
-                k_str = key.capitalize().replace("_", " ")
-                if k_str in el.data and (not str(el.data[k_str]).startswith("no data")):
-                    assert getattr(el, key) is not None
-                elif key == "long_name":
+            for elements in keys:
+                key_str = elements.capitalize().replace("_", " ")
+                if key_str in el.data and (not str(el.data[key_str]).startswith("no data")):
+                    assert getattr(el, elements) is not None
+                elif elements == "long_name":
                     assert el.long_name == el.data["Name"]
-                elif key == "iupac_ordering":
+                elif elements == "iupac_ordering":
                     assert "IUPAC ordering" in el.data
-                    assert getattr(el, key) is not None
-            el = Element.from_Z(idx)
+                    assert getattr(el, elements) is not None
+
             if len(el.oxidation_states) > 0:
                 assert max(el.oxidation_states) == el.max_oxidation_state
                 assert min(el.oxidation_states) == el.min_oxidation_state
 
-            if el.symbol not in ["He", "Ne", "Ar"]:
+            if el.symbol not in {"He", "Ne", "Ar"}:
                 assert el.X > 0, f"No electroneg for {el}"
 
+            # check atomic_orbitals_eV is Ha_to_eV * atomic_orbitals
+        for el in Element:
+            if el.atomic_orbitals is None:
+                continue
+            assert el.atomic_orbitals_eV == approx(
+                {orb: energy * Ha_to_eV for orb, energy in el.atomic_orbitals.items()}
+            )
+
         with pytest.raises(ValueError, match="Unexpected atomic number Z=1000"):
             Element.from_Z(1000)
 
@@ -366,7 +382,7 @@ class ElementTestCase(PymatgenTest):
         assert [el.atomic_mass for el in elems] == [1.00794, 2.013553212712, 3.0155007134]
 
 
-class SpeciesTestCase(PymatgenTest):
+class TestSpecies(PymatgenTest):
     def setUp(self):
         self.specie1 = Species.from_str("Fe2+")
         self.specie2 = Species("Fe", 3)
@@ -403,9 +419,7 @@ class SpeciesTestCase(PymatgenTest):
         assert self.specie4.spin == 5
 
     def test_deepcopy(self):
-        el1 = Species("Fe4+")
-        el2 = Species("Na1+")
-        elem_list = [el1, el2]
+        elem_list = [Species("Fe4+"), Species("Na1+")]
         assert elem_list == deepcopy(elem_list), "Deepcopy operation doesn't produce exact copy."
 
     def test_pickle(self):
@@ -443,8 +457,8 @@ class SpeciesTestCase(PymatgenTest):
         with pytest.raises(ValueError, match="Invalid coordination or spin config"):
             Species("Fe", 2).get_crystal_field_spin("hex")
 
-        s = Species("Co", 3).get_crystal_field_spin("tet", spin_config="low")
-        assert s == 2
+        spin = Species("Co", 3).get_crystal_field_spin("tet", spin_config="low")
+        assert spin == 2
 
     def test_get_nmr_mom(self):
         assert Species("H").get_nmr_quadrupole_moment() == 2.860
@@ -517,15 +531,23 @@ class SpeciesTestCase(PymatgenTest):
         ("P5+", "P", 5),
         ("Na0+", "Na", 0),
         ("Na0-", "Na", 0),
+        ("C0.53-", "C", -0.53),
+        ("Tc3.498+", "Tc", 3.498),
     ],
 )
 def test_symbol_oxi_state_str(symbol_oxi, expected_element, expected_oxi_state):
     species = Species(symbol_oxi)
     assert species._el.symbol == expected_element
-    assert species._oxi_state == expected_oxi_state
+    assert species._oxi_state == pytest.approx(expected_oxi_state, rel=1.0e-6)
 
 
-class DummySpeciesTestCase(unittest.TestCase):
+def test_symbol_oxi_state_str_raises():
+    symbol = "Fe2.5f2123+"  # invalid oxidation state
+    with pytest.raises(ParseError, match=re.escape(f"Failed to parse {symbol=}")):
+        _ = Species(symbol)
+
+
+class TestDummySpecies:
     def test_init(self):
         self.specie1 = DummySpecies("X")
         with pytest.raises(ValueError, match="Xe contains Xe, which is a valid element symbol"):
@@ -561,29 +583,50 @@ class DummySpeciesTestCase(unittest.TestCase):
 
     def test_pickle(self):
         el1 = DummySpecies("X", 3)
-        o = pickle.dumps(el1)
-        assert el1 == pickle.loads(o)
+        pickled = pickle.dumps(el1)
+        assert el1 == pickle.loads(pickled)
 
     def test_sort(self):
-        r = sorted([Element.Fe, DummySpecies("X")])
-        assert r == [DummySpecies("X"), Element.Fe]
+        Fe, X = Element.Fe, DummySpecies("X")
+        assert sorted([Fe, X]) == [X, Fe]
         assert DummySpecies("X", 3) < DummySpecies("X", 4)
 
         sp = Species("Fe", 2, spin=5)
         with pytest.raises(AttributeError) as exc:
             sp.spin = 6
 
+        # for some reason different message on Windows and Mac. on Linux: 'can't set attribute'
         assert "can't set attribute" in str(exc.value) or "property 'spin' of 'Species' object has no setter" in str(
             exc.value
-        )  # 'can't set attribute' on Linux, for some reason different message on Windows and Mac
+        )
         assert sp.spin == 5
 
+    def test_not_implemented(self):
+        with pytest.raises(NotImplementedError):
+            _ = Species("Fe", 2).full_electronic_structure
+        with pytest.raises(NotImplementedError):
+            _ = Species("Fe", 2).electronic_structure
+        with pytest.raises(NotImplementedError):
+            _ = Species("Fe", 2).valence
 
-class TestFunc(unittest.TestCase):
-    def test_get_el_sp(self):
-        assert get_el_sp("Fe2+") == Species("Fe", 2)
-        assert get_el_sp("3") == Element.Li
-        assert get_el_sp("3.0") == Element.Li
-        assert get_el_sp("U") == Element.U
-        assert get_el_sp("X2+") == DummySpecies("X", 2)
-        assert get_el_sp("Mn3+") == Species("Mn", 3)
+
+def test_get_el_sp():
+    assert get_el_sp("Fe2+") == Species("Fe", 2)
+    assert get_el_sp("3") == Element.Li
+    assert get_el_sp(5) == Element.B
+    assert get_el_sp("3.0") == Element.Li
+    assert get_el_sp("+3.0") == Element.Li
+    assert get_el_sp(2.0) == Element.He
+    assert get_el_sp("U") == Element.U
+    assert get_el_sp("X2+") == DummySpecies("X", 2)
+    assert get_el_sp("Mn3+") == Species("Mn", 3)
+    assert get_el_sp("X2+spin=5") == DummySpecies("X", 2, spin=5)
+
+    with pytest.raises(ValueError, match="Can't parse Element or Species from None"):
+        get_el_sp(None)
+
+
+def test_element_type():
+    assert isinstance(ElementType.actinoid, Enum)
+    assert isinstance(ElementType.metalloid, Enum)
+    assert len(ElementType) == 18
