@@ -2,11 +2,12 @@ from __future__ import annotations
 
 import json
 import os
-import unittest
 from shutil import which
+from unittest import TestCase
 
 import matplotlib.pyplot as plt
 import numpy as np
+import pytest
 from matplotlib import rc
 from numpy.testing import assert_allclose
 from pytest import approx
@@ -29,14 +30,16 @@ from pymatgen.electronic_structure.plotter import (
     plot_ellipsoid,
 )
 from pymatgen.io.vasp import Vasprun
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, VASP_IN_DIR, VASP_OUT_DIR, PymatgenTest
+
+BAND_TEST_DIR = f"{TEST_FILES_DIR}/electronic_structure/bandstructure"
 
 rc("text", usetex=False)  # Disabling latex is needed for this test to work.
 
 
 class TestDosPlotter(PymatgenTest):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/complete_dos.json") as file:
+        with open(f"{BAND_TEST_DIR}/../dos/complete_dos.json") as file:
             self.dos = CompleteDos.from_dict(json.load(file))
             self.plotter = DosPlotter(sigma=0.2, stack=True)
 
@@ -67,7 +70,7 @@ class TestDosPlotter(PymatgenTest):
         # reproduces the same energy and DOS axis limits
         self.plotter.add_dos_dict(self.dos.get_element_dos(), key_sort_func=lambda x: x.X)
         # Contains energy and DOS limits and expected results
-        with open(f"{TEST_FILES_DIR}/complete_dos_limits.json") as file:
+        with open(f"{BAND_TEST_DIR}/../plotter/complete_dos_limits.json") as file:
             limits_results = json.load(file)
 
         for item in limits_results:
@@ -87,18 +90,18 @@ class TestDosPlotter(PymatgenTest):
 
 class TestBSPlotter(PymatgenTest):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/CaO_2605_bandstructure.json") as file:
+        with open(f"{BAND_TEST_DIR}/CaO_2605_bandstructure.json") as file:
             dct = json.loads(file.read())
             self.bs = BandStructureSymmLine.from_dict(dct)
             self.plotter = BSPlotter(self.bs)
 
         assert len(self.plotter._bs) == 1, "wrong number of band objects"
 
-        with open(f"{TEST_FILES_DIR}/N2_12103_bandstructure.json") as file:
+        with open(f"{BAND_TEST_DIR}/N2_12103_bandstructure.json") as file:
             dct = json.loads(file.read())
             self.sbs_sc = BandStructureSymmLine.from_dict(dct)
 
-        with open(f"{TEST_FILES_DIR}/C_48_bandstructure.json") as file:
+        with open(f"{BAND_TEST_DIR}/C_48_bandstructure.json") as file:
             dct = json.loads(file.read())
             self.sbs_met = BandStructureSymmLine.from_dict(dct)
 
@@ -137,7 +140,7 @@ class TestBSPlotter(PymatgenTest):
         assert (
             len(self.plotter.bs_plot_data()["distances"][0]) == 16
         ), "wrong number of distances in the first sequence of branches"
-        assert sum(len(e) for e in self.plotter.bs_plot_data()["distances"]) == 160, "wrong number of distances"
+        assert sum(len(dist) for dist in self.plotter.bs_plot_data()["distances"]) == 160, "wrong number of distances"
 
         length = len(self.plotter.bs_plot_data(split_branches=False)["distances"][0])
         assert length == 144, "wrong number of distances in the first sequence of branches"
@@ -178,32 +181,43 @@ class TestBSPlotter(PymatgenTest):
         plt.close("all")
 
 
-class TestBSPlotterProjected(unittest.TestCase):
+class TestBSPlotterProjected(TestCase):
     def setUp(self):
-        with open(f"{TEST_FILES_DIR}/Cu2O_361_bandstructure.json") as file:
-            dct = json.load(file)
-            self.bs = BandStructureSymmLine.from_dict(dct)
-            self.plotter = BSPlotterProjected(self.bs)
+        with open(f"{BAND_TEST_DIR}/Cu2O_361_bandstructure.json") as file:
+            self.bs_Cu2O = BandStructureSymmLine.from_dict(json.load(file))
+        self.plotter_Cu2O = BSPlotterProjected(self.bs_Cu2O)
+
+        with open(f"{TEST_FILES_DIR}/electronic_structure/boltztrap2/PbTe_bandstructure.json") as file:
+            self.bs_PbTe = BandStructureSymmLine.from_dict(json.load(file))
 
-    # Minimal baseline testing for get_plot. not a true test. Just checks that
-    # it can actually execute.
     def test_methods(self):
-        self.plotter.get_elt_projected_plots()
-        self.plotter.get_elt_projected_plots_color()
-        self.plotter.get_projected_plots_dots({"Cu": ["d", "s"], "O": ["p"]})
-        self.plotter.get_projected_plots_dots_patom_pmorb(
+        # Minimal baseline testing for get_plot. not a true test. Just checks that
+        # it can actually execute.
+        self.plotter_Cu2O.get_elt_projected_plots()
+        self.plotter_Cu2O.get_elt_projected_plots_color()
+        axes = self.plotter_Cu2O.get_projected_plots_dots({"Cu": ["d", "s"], "O": ["p"]})
+        assert len(axes) == 4, f"{len(axes)=}"
+        assert len(axes[0].get_lines()) == 4903, f"{len(axes[0].get_lines())=}"
+        assert len(axes[-1].get_lines()) == 0, f"{len(axes[-1].get_lines())=}"
+        ax = self.plotter_Cu2O.get_projected_plots_dots_patom_pmorb(
             {"Cu": ["dxy", "s", "px"], "O": ["px", "py", "pz"]},
             {"Cu": [3, 5], "O": [1]},
         )
+        assert isinstance(ax, plt.Axes)
+        assert len(ax.get_lines()) == 44_127
+        assert ax.get_ylim() == pytest.approx((-4.0, 4.5047))
+
+        with pytest.raises(ValueError, match="Can't plot projections on a band structure without projections data"):
+            BSPlotterProjected(self.bs_PbTe)
 
 
-class TestBSDOSPlotter(unittest.TestCase):
+class TestBSDOSPlotter:
     # Minimal baseline testing for get_plot. not a true test. Just checks that
     # it can actually execute.
     def test_methods(self):
-        vasp_run = Vasprun(f"{TEST_FILES_DIR}/vasprun_Si_bands.xml")
+        vasp_run = Vasprun(f"{VASP_OUT_DIR}/vasprun_Si_bands.xml.gz")
         plotter = BSDOSPlotter()
-        band_struct = vasp_run.get_band_structure(kpoints_filename=f"{TEST_FILES_DIR}/KPOINTS_Si_bands")
+        band_struct = vasp_run.get_band_structure(kpoints_filename=f"{VASP_IN_DIR}/KPOINTS_Si_bands")
         ax = plotter.get_plot(band_struct)
         assert isinstance(ax, plt.Axes)
         plt.close()
@@ -212,33 +226,33 @@ class TestBSDOSPlotter(unittest.TestCase):
         assert isinstance(dos_ax, plt.Axes)
         plt.close("all")
 
-        with open(f"{TEST_FILES_DIR}/SrBa2Sn2O7.json") as file:
+        with open(f"{TEST_FILES_DIR}/electronic_structure/plotter/SrBa2Sn2O7.json") as file:
             band_struct_dict = json.load(file)
         # generate random projections
         data_structure = [[[[0 for _ in range(12)] for _ in range(9)] for _ in range(70)] for _ in range(90)]
         band_struct_dict["projections"]["1"] = data_structure
         dct = band_struct_dict["projections"]["1"]
-        for i in range(len(dct)):
-            for j in range(len(dct[i])):
-                for k in range(len(dct[i][j])):
-                    for m in range(len(dct[i][j][k])):
-                        dct[i][j][k][m] = 0
+        for ii in range(len(dct)):
+            for jj in range(len(dct[ii])):
+                for kk in range(len(dct[ii][jj])):
+                    for ll in range(len(dct[ii][jj][kk])):
+                        dct[ii][jj][kk][ll] = 0
                         # d[i][j][k][m] = np.random.rand()
                     # generate random number for two atoms
                     a = np.random.randint(0, 7)
                     b = np.random.randint(0, 7)
                     # c = np.random.randint(0,7)
-                    dct[i][j][k][a] = np.random.rand()
-                    dct[i][j][k][b] = np.random.rand()
+                    dct[ii][jj][kk][a] = np.random.rand()
+                    dct[ii][jj][kk][b] = np.random.rand()
                     # d[i][j][k][c] = np.random.rand()
         band_struct = BandStructureSymmLine.from_dict(band_struct_dict)
         ax = plotter.get_plot(band_struct)
         assert isinstance(ax, plt.Axes)
 
 
-class TestPlotBZ(unittest.TestCase):
+class TestPlotBZ(TestCase):
     def setUp(self):
-        self.rec_latt = Structure.from_file(f"{TEST_FILES_DIR}/Si.cssr").lattice.reciprocal_lattice
+        self.rec_latt = Structure.from_file(f"{TEST_FILES_DIR}/io/cssr/Si.cssr").lattice.reciprocal_lattice
         self.kpath = [[[0.0, 0.0, 0.0], [0.5, 0.0, 0.5], [0.5, 0.25, 0.75], [0.375, 0.375, 0.75]]]
         self.labels = {
             "\\Gamma": [0.0, 0.0, 0.0],
@@ -280,8 +294,8 @@ class TestPlotBZ(unittest.TestCase):
         )
 
 
-@unittest.skipIf(not which("x_trans"), "No x_trans executable found")
-class TestBoltztrapPlotter(unittest.TestCase):
+@pytest.mark.skipif(not which("x_trans"), reason="No x_trans executable found")
+class TestBoltztrapPlotter(TestCase):
     def setUp(self):
         bz = BoltztrapAnalyzer.from_files(f"{TEST_FILES_DIR}/boltztrap/transp/")
         self.plotter = BoltztrapPlotter(bz)
@@ -422,10 +436,10 @@ class TestBoltztrapPlotter(unittest.TestCase):
 
 class TestCohpPlotter(PymatgenTest):
     def setUp(self):
-        path = f"{TEST_FILES_DIR}/cohp/complete_cohp_lobster.json"
+        path = f"{TEST_FILES_DIR}/electronic_structure/cohp/complete_cohp_lobster.json"
         with open(path) as file:
             self.cohp = CompleteCohp.from_dict(json.load(file))
-        path = f"{TEST_FILES_DIR}/cohp/complete_coop_lobster.json"
+        path = f"{TEST_FILES_DIR}/electronic_structure/cohp/complete_coop_lobster.json"
         with open(path) as file:
             self.coop = CompleteCohp.from_dict(json.load(file))
         self.cohp_plot = CohpPlotter(zero_at_efermi=False)
