@@ -23,7 +23,7 @@ __maintainer__ = "Samuel Blau"
 __email__ = "samblau1@gmail.com"
 
 
-TEST_DIR = f"{TEST_FILES_DIR}/molecules/new_qchem_files"
+TEST_DIR = f"{TEST_FILES_DIR}/io/qchem/new_qchem_files"
 
 
 class TestQChemDictSet(PymatgenTest):
@@ -383,7 +383,7 @@ class TestQChemDictSet(PymatgenTest):
         os.remove("solvent_data")
 
     def test_solvation_warnings(self):
-        """Tests warnings / errors resulting from nonsensical overwrite_inputs."""
+        """Test warnings / errors resulting from nonsensical overwrite_inputs."""
         test_molecule = QCInput.from_file(f"{TEST_DIR}/pcm.qin").molecule
         with pytest.raises(RuntimeError, match="CMIRS is only parameterized"):
             QChemDictSet(
