@@ -1,7 +1,5 @@
 from __future__ import annotations
 
-import unittest
-
 import numpy as np
 import pytest
 from pytest import approx
@@ -11,7 +9,7 @@ from pymatgen.core import Composition, DummySpecies, Element, Lattice, Species,
 from pymatgen.electronic_structure.core import Magmom
 from pymatgen.io.cif import CifBlock, CifParser, CifWriter
 from pymatgen.symmetry.structure import SymmetrizedStructure
-from pymatgen.util.testing import TEST_FILES_DIR, PymatgenTest
+from pymatgen.util.testing import TEST_FILES_DIR, VASP_IN_DIR, PymatgenTest
 
 try:
     import pybtex
@@ -19,9 +17,12 @@ except ImportError:
     pybtex = None
 
 
+MCIF_TEST_DIR = f"{TEST_FILES_DIR}/io/cif/mcif"
+
+
 class TestCifBlock(PymatgenTest):
     def test_to_str(self):
-        with open(f"{TEST_FILES_DIR}/Graphite.cif") as file:
+        with open(f"{TEST_FILES_DIR}/cif/Graphite.cif") as file:
             cif_str = file.read()
         cif_block = CifBlock.from_str(cif_str)
         cif_str_2 = str(CifBlock.from_str(str(cif_block)))
@@ -160,11 +161,11 @@ loop_
 
 class TestCifIO(PymatgenTest):
     def test_cif_parser(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/LiFePO4.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/LiFePO4.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Li4 Fe4 P4 O16", "Incorrectly parsed cif."
 
-        parser = CifParser(f"{TEST_FILES_DIR}/V2O3.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/V2O3.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "V4 O6"
 
@@ -180,19 +181,20 @@ class TestCifIO(PymatgenTest):
         """
         assert parser.get_bibtex_string().strip() == bibtex_str.strip()
 
-        parser = CifParser(f"{TEST_FILES_DIR}/Li2O.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Li2O.cif")
         prim = parser.parse_structures()[0]
         assert prim.formula == "Li8 O4"
         conv = parser.parse_structures(primitive=False)[0]
         assert conv.formula == "Li8 O4"
 
         # test for disordered structures
-        parser = CifParser(f"{TEST_FILES_DIR}/Li10GeP2S12.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Li10GeP2S12.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Li20.2 Ge2.06 P3.94 S24", "Incorrectly parsed cif."
 
-        with open(f"{TEST_FILES_DIR}/FePO4.cif") as cif_file:
+        with open(f"{TEST_FILES_DIR}/cif/FePO4.cif") as cif_file:
             cif_str = cif_file.read()
+
         parser = CifParser.from_str(cif_str)
         struct = parser.parse_structures(primitive=False)[0]
         assert struct.formula == "Fe4 P4 O16"
@@ -203,17 +205,17 @@ class TestCifIO(PymatgenTest):
         assert struct.lattice.beta == approx(92)
         assert struct.lattice.gamma == approx(93)
 
-        parser = CifParser(f"{TEST_FILES_DIR}/srycoo.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/srycoo.cif")
         assert parser.parse_structures()[0].formula == "Sr11.2 Y4.8 Co16 O42"
 
         # Test with a decimal Xyz. This should parse as two atoms in
         # conventional cell if it is correct, one if not.
-        parser = CifParser(f"{TEST_FILES_DIR}/Fe.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Fe.cif")
         assert len(parser.parse_structures(primitive=False)[0]) == 2
         assert not parser.has_errors
 
     def test_get_symmetrized_structure(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/Li2O.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Li2O.cif")
         sym_structure = parser.parse_structures(primitive=False, symmetrized=True)[0]
         structure = parser.parse_structures(primitive=False, symmetrized=False)[0]
         assert isinstance(sym_structure, SymmetrizedStructure)
@@ -222,11 +224,11 @@ class TestCifIO(PymatgenTest):
         assert set(sym_structure.labels) == {"O1", "Li1"}
 
     def test_site_symbol_preference(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/site_type_symbol_test.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/site_type_symbol_test.cif")
         assert parser.parse_structures()[0].formula == "Ge1.6 Sb1.6 Te4"
 
     def test_implicit_hydrogen(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/Senegalite_implicit_hydrogen.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Senegalite_implicit_hydrogen.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Al8 P4 O32"
             assert sum(struct.site_properties["implicit_hydrogens"]) == 20
@@ -235,7 +237,7 @@ class TestCifIO(PymatgenTest):
             "parsed structure unlikely to be suitable for use "
             "in calculations unless hydrogens added." in parser.warnings
         )
-        parser = CifParser(f"{TEST_FILES_DIR}/cif_implicit_hydrogens_cod_1011130.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/cif_implicit_hydrogens_cod_1011130.cif")
         struct = parser.parse_structures()[0]
         assert (
             "Structure has implicit hydrogens defined, "
@@ -244,7 +246,7 @@ class TestCifIO(PymatgenTest):
         )
 
     def test_site_labels(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/garnet.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/garnet.cif")
         struct = parser.parse_structures(primitive=True)[0]
 
         # ensure structure has correct number of labels
@@ -261,14 +263,14 @@ class TestCifIO(PymatgenTest):
             assert site.label.startswith(site.specie.name)
 
         # ensure multiple species with different names have correct labels
-        parser2 = CifParser(f"{TEST_FILES_DIR}/Fe3O4.cif")
+        parser2 = CifParser(f"{TEST_FILES_DIR}/cif/Fe3O4.cif")
         struct2 = parser2.parse_structures(primitive=False)[0]
 
         expected_site_names2 = {*"O1 O2 O3 O4 O5 O6 O7 O8 Fe9 Fe10 Fe11 Fe12 Fe13 Fe14".split()}
         assert set(struct2.labels) == expected_site_names2
 
     def test_cif_writer_labeled(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/garnet.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/garnet.cif")
         struct = parser.parse_structures()[0]
         for idx, site in enumerate(struct):
             site.label = f"my_{site.specie.name}{idx}"
@@ -283,19 +285,19 @@ class TestCifIO(PymatgenTest):
         # Below are 10 tests for CIFs from the Springer Materials/Pauling file DBs.
 
         # Partial occupancy on sites, incorrect label, previously unparsable
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1928405.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1928405.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Er1 Mn3.888 Fe2.112 Sn6"
         assert parser.has_errors
 
         # Partial occupancy on sites, previously parsed as an ordered structure
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1011081.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1011081.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Zr0.4 Nb1.6"
         assert parser.has_errors
 
         # Partial occupancy on sites, incorrect label, previously unparsable
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1615854.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1615854.cif")
         for idx, struct in enumerate(parser.parse_structures()):
             if idx == 0:
                 assert struct.formula == "Na2 Al2 Si6 O16"
@@ -304,19 +306,19 @@ class TestCifIO(PymatgenTest):
         assert parser.has_errors
 
         # Partial occupancy on sites, incorrect label, previously unparsable
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1622133.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1622133.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Ca0.184 Mg13.016 Fe2.8 Si16 O48"
         assert parser.has_errors
 
         # Partial occupancy on sites, previously parsed as an ordered structure
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1908491.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1908491.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Mn0.96 Zn1.04 Ga4 Se8"
         assert parser.has_errors
 
         # Partial occupancy on sites, incorrect label, previously unparsable
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1811457.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1811457.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Ba8 Mg2.4 Zr0.8 Ta4.8 O24"
         assert parser.has_errors
@@ -327,37 +329,37 @@ class TestCifIO(PymatgenTest):
         # corresponding symbol is "NH3". Since, the label and symbol are switched
         # in CIFs from Springer Materials/Pauling file DBs, CifParser parses the
         # element as "Nh" (Nihonium).
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1002871.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1002871.cif")
         assert parser.parse_structures()[0].formula == "Cu2 Br4 Nh12"
         assert parser.parse_structures()[1].formula == "Cu2 Br8 Nh12"
         assert parser.has_errors
 
         # Incomplete powder diffraction data, previously unparsable
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1704003.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1704003.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Rb4 Mn2 F12"
         assert parser.has_errors
 
         # Unparsable species 'OH/OH2', previously parsed as "O"
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1500382.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1500382.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Mg6 B2 O6 F1.764"
         assert parser.has_errors
 
         # Unparsable species 'OH/OH2', previously parsed as "O"
-        parser = CifParser(f"{TEST_FILES_DIR}/PF_sd_1601634.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/PF_sd_1601634.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Zn2.58 Fe1.38 As4 Pb2.04 O16"
 
     def test_cif_parser_cod(self):
         """Parsing problematic CIF files from the COD database."""
         # Symbol in capital letters
-        parser = CifParser(f"{TEST_FILES_DIR}/Cod_2100513.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Cod_2100513.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Ca4 Nb2.0 Al2 O12"
 
         # Label in capital letters
-        parser = CifParser(f"{TEST_FILES_DIR}/Cod_4115344.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/Cod_4115344.cif")
         for struct in parser.parse_structures():
             assert struct.formula == "Mo8 P4 H120 C120 I8 O8"
 
@@ -400,13 +402,13 @@ class TestCifIO(PymatgenTest):
             "SH": "S",
         }
 
-        for e in Element:
-            name = e.name
+        for elem in Element:
+            name = elem.name
             test_cases[name] = name
             if len(name) == 2:
                 test_cases[name.upper()] = name
                 test_cases[f"{name.upper()}1"] = name
-                test_cases[name.upper() + "A"] = name
+                test_cases[f"{name.upper()}A"] = name
             test_cases[f"{name}1"] = name
             test_cases[f"{name}2"] = name
             test_cases[f"{name}3"] = name
@@ -415,12 +417,12 @@ class TestCifIO(PymatgenTest):
         special = {"Hw": "H", "Ow": "O", "Wat": "O", "wat": "O", "OH": "", "OH2": ""}
         test_cases.update(special)
 
-        parser = CifParser(f"{TEST_FILES_DIR}/LiFePO4.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/LiFePO4.cif")
         for sym, expected_symbol in test_cases.items():
             assert parser._parse_symbol(sym) == expected_symbol
 
     def test_cif_writer(self):
-        filepath = f"{TEST_FILES_DIR}/POSCAR"
+        filepath = f"{VASP_IN_DIR}/POSCAR"
         struct = Structure.from_file(filepath)
         writer = CifWriter(struct, symprec=0.01)
         answer = """# generated using pymatgen
@@ -465,42 +467,42 @@ loop_
             assert l1.strip() == l2.strip()
 
     def test_symmetrized(self):
-        filepath = f"{TEST_FILES_DIR}/POSCAR"
+        filepath = f"{VASP_IN_DIR}/POSCAR"
         struct = Structure.from_file(filepath)
         writer = CifWriter(struct, symprec=0.1)
 
         cif = CifParser.from_str(str(writer))
-        m = StructureMatcher()
+        matcher = StructureMatcher()
 
-        assert m.fit(cif.parse_structures()[0], struct)
+        assert matcher.fit(cif.parse_structures()[0], struct)
 
         # for l1, l2 in zip(str(writer).split("\n"), answer.split("\n")):
         #     assert l1.strip() == l2.strip()
 
-        struct = Structure.from_file(f"{TEST_FILES_DIR}/LiFePO4.cif")
+        struct = Structure.from_file(f"{TEST_FILES_DIR}/cif/LiFePO4.cif")
         writer = CifWriter(struct, symprec=0.1)
         s2 = CifParser.from_str(str(writer)).parse_structures()[0]
 
-        assert m.fit(struct, s2)
+        assert matcher.fit(struct, s2)
 
         struct = self.get_structure("Li2O")
         writer = CifWriter(struct, symprec=0.1)
         s2 = CifParser.from_str(str(writer)).parse_structures()[0]
-        assert m.fit(struct, s2)
+        assert matcher.fit(struct, s2)
 
         # test angle tolerance.
-        struct = Structure.from_file(f"{TEST_FILES_DIR}/LiFePO4.cif")
+        struct = Structure.from_file(f"{TEST_FILES_DIR}/cif/LiFePO4.cif")
         writer = CifWriter(struct, symprec=0.1, angle_tolerance=0)
         dct = next(iter(writer.cif_file.data.values()))
         assert dct["_symmetry_Int_Tables_number"] == 14
-        struct = Structure.from_file(f"{TEST_FILES_DIR}/LiFePO4.cif")
+        struct = Structure.from_file(f"{TEST_FILES_DIR}/cif/LiFePO4.cif")
         writer = CifWriter(struct, symprec=0.1, angle_tolerance=2)
         dct = next(iter(writer.cif_file.data.values()))
         assert dct["_symmetry_Int_Tables_number"] == 62
 
     def test_disordered(self):
         si = Element("Si")
-        n = Element("N")
+        nitrogen = Element("N")
         coords = []
         coords.extend((np.array([0, 0, 0]), np.array([0.75, 0.5, 0.75])))
         lattice = [
@@ -508,7 +510,7 @@ loop_
             [1.9200989668, 3.3257101909, 0.00],
             [0.00, -2.2171384943, 3.1355090603],
         ]
-        struct = Structure(lattice, [si, {si: 0.5, n: 0.5}], coords)
+        struct = Structure(lattice, [si, {si: 0.5, nitrogen: 0.5}], coords)
         writer = CifWriter(struct)
         answer = """# generated using pymatgen
 data_Si1.5N0.5
@@ -544,7 +546,7 @@ loop_
             assert l1.strip() == l2.strip()
 
     def test_cif_writer_without_refinement(self):
-        si2 = Structure.from_file(f"{TEST_FILES_DIR}/abinit/si.cif")
+        si2 = Structure.from_file(f"{TEST_FILES_DIR}/io/abinit/si.cif")
 
         writer = CifWriter(si2, symprec=1e-3, significant_figures=10, refine_struct=False)
         cif_str = str(writer)
@@ -555,7 +557,7 @@ loop_
     def test_specie_cif_writer(self):
         si4 = Species("Si", 4)
         si3 = Species("Si", 3)
-        n = DummySpecies("X", -3)
+        dummy_spec = DummySpecies("X", -3)
         coords = []
         coords.extend((np.array([0.5, 0.5, 0.5]), np.array([0.75, 0.5, 0.75]), np.array([0, 0, 0])))
         lattice = [
@@ -563,7 +565,7 @@ loop_
             [1.9200989668, 3.3257101909, 0.00],
             [0.00, -2.2171384943, 3.1355090603],
         ]
-        struct = Structure(lattice, [n, {si3: 0.5, n: 0.5}, si4], coords)
+        struct = Structure(lattice, [dummy_spec, {si3: 0.5, dummy_spec: 0.5}, si4], coords)
         writer = CifWriter(struct)
         answer = """# generated using pymatgen
 data_X1.5Si1.5
@@ -610,12 +612,12 @@ loop_
         assert struct.composition == s2.composition
 
     def test_primes(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/C26H16BeN2O2S2.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/C26H16BeN2O2S2.cif")
         for struct in parser.parse_structures(primitive=False):
             assert struct.composition == 8 * Composition("C26H16BeN2O2S2")
 
     def test_missing_atom_site_type_with_oxi_states(self):
-        parser = CifParser(f"{TEST_FILES_DIR}/P24Ru4H252C296S24N16.cif")
+        parser = CifParser(f"{TEST_FILES_DIR}/cif/P24Ru4H252C296S24N16.cif")
         comp = Composition({"S0+": 24, "Ru0+": 4, "H0+": 252, "C0+": 296, "N0+": 16, "P0+": 24})
         for struct in parser.parse_structures(primitive=False):
             assert struct.composition == comp
@@ -711,7 +713,7 @@ loop_
 """
         parser = CifParser.from_str(cif_structure)
         s_test = parser.parse_structures(primitive=False)[0]
-        filepath = f"{TEST_FILES_DIR}/POSCAR"
+        filepath = f"{VASP_IN_DIR}/POSCAR"
         struct = Structure.from_file(filepath)
 
         sm = StructureMatcher(stol=0.05, ltol=0.01, angle_tol=0.1)
@@ -729,41 +731,59 @@ loop_
         cb2 = CifBlock.from_str(str(cb))
         assert cb == cb2
 
-    def test_bad_cif(self):
-        filepath = f"{TEST_FILES_DIR}/bad_occu.cif"
+    def test_bad_occu(self):
+        filepath = f"{TEST_FILES_DIR}/cif/bad_occu.cif"
         parser = CifParser(filepath)
         with pytest.raises(
-            ValueError, match="No structure parsed for section 1 in CIF.\nSpecies occupancies sum to more than 1!"
+            ValueError, match="No structure parsed for section 1 in CIF.\nOccupancy 1.556 exceeded tolerance."
         ):
             parser.parse_structures(on_error="raise")
         parser = CifParser(filepath, occupancy_tolerance=2)
         struct = parser.parse_structures()[0]
         assert struct[0].species["Al3+"] == approx(0.778)
 
+    def test_not_check_occu(self):
+        # Test large occupancy with check_occu turned off
+        with open(f"{TEST_FILES_DIR}/cif/site_type_symbol_test.cif") as cif_file:
+            cif_str = cif_file.read()
+        cif_str = cif_str.replace("Te    Te 1.0000", "Te_label    Te 10.0", 1)
+
+        with pytest.warns(
+            UserWarning, match=r"Issues encountered while parsing CIF: Some occupancies \(\[10\.0\]\) sum to > 1!"
+        ):
+            structs = CifParser.from_str(cif_str).parse_structures(check_occu=False)
+
+        assert len(structs) > 0
+        assert set(structs[0].labels) == {"Te_label", "Ge"}
+
     def test_one_line_symm(self):
-        f = f"{TEST_FILES_DIR}/OneLineSymmP1.cif"
-        parser = CifParser(f)
+        cif_file = f"{TEST_FILES_DIR}/cif/OneLineSymmP1.cif"
+        parser = CifParser(cif_file)
         struct = parser.parse_structures()[0]
         assert struct.formula == "Ga4 Pb2 O8"
 
     def test_no_symmops(self):
-        f = f"{TEST_FILES_DIR}/nosymm.cif"
-        parser = CifParser(f)
+        cif_file = f"{TEST_FILES_DIR}/cif/nosymm.cif"
+        parser = CifParser(cif_file)
         struct = parser.parse_structures()[0]
         assert struct.formula == "H96 C60 O8"
 
     def test_dot_positions(self):
-        f = f"{TEST_FILES_DIR}/ICSD59959.cif"
-        parser = CifParser(f)
+        cif_file = f"{TEST_FILES_DIR}/cif/ICSD59959.cif"
+        parser = CifParser(cif_file)
         struct = parser.parse_structures()[0]
         assert struct.formula == "K1 Mn1 F3"
 
     def test_replacing_finite_precision_frac_coords(self):
-        cif = f"{TEST_FILES_DIR}/cif_finite_precision_frac_coord_error.cif"
+        cif = f"{TEST_FILES_DIR}/cif/cif_finite_precision_frac_coord_error.cif"
         parser = CifParser(cif)
-        warn_msg = "4 fractional coordinates rounded to ideal values to avoid issues with finite precision."
-        with pytest.warns(UserWarning, match=warn_msg):
+        with pytest.warns(UserWarning) as record:
             struct = parser.parse_structures()[0]
+
+        assert len(record) == 3
+        warn_msg = "4 fractional coordinates rounded to ideal values to avoid issues with finite precision."
+        assert warn_msg in str(record[-1])
+
         assert str(struct.composition) == "N5+72"
         assert warn_msg in parser.warnings
 
@@ -837,7 +857,7 @@ Si1 Si 0 0 0 1 0.0
             parser.parse_structures()
 
     def test_no_check_occu(self):
-        with open(f"{TEST_FILES_DIR}/site_type_symbol_test.cif") as cif_file:
+        with open(f"{TEST_FILES_DIR}/cif/site_type_symbol_test.cif") as cif_file:
             cif_str = cif_file.read()
         cif_str = cif_str.replace("Te    Te 1.0000", "Te    Te 1.5000", 1)
 
@@ -851,7 +871,7 @@ Si1 Si 0 0 0 1 0.0
             assert structs[0].species.as_dict()["Te"] == 1.5
 
     def test_cif_writer_write_file(self):
-        struct1 = Structure.from_file(f"{TEST_FILES_DIR}/POSCAR")
+        struct1 = Structure.from_file(f"{VASP_IN_DIR}/POSCAR")
         out_path = f"{self.tmp_path}/test.cif"
         CifWriter(struct1).write_file(out_path)
         read_structs = CifParser(out_path).parse_structures()
@@ -859,7 +879,7 @@ Si1 Si 0 0 0 1 0.0
         assert struct1.matches(read_structs[0])
 
         # test write_file append mode='a'
-        struct2 = Structure.from_file(f"{TEST_FILES_DIR}/Graphite.cif")
+        struct2 = Structure.from_file(f"{TEST_FILES_DIR}/cif/Graphite.cif")
         CifWriter(struct2).write_file(out_path, mode="a")
 
         read_structs = CifParser(out_path).parse_structures()
@@ -867,14 +887,14 @@ Si1 Si 0 0 0 1 0.0
         assert [x.formula for x in read_structs] == ["Fe4 P4 O16", "C4"]
 
     def test_valid_cif(self):
-        cif = CifParser(f"{TEST_FILES_DIR}/CsI3Pb.cif")
-        structure = Structure.from_file(f"{TEST_FILES_DIR}/CsI3Pb.cif")
+        cif = CifParser(f"{TEST_FILES_DIR}/cif/CsI3Pb.cif")
+        structure = Structure.from_file(f"{TEST_FILES_DIR}/cif/CsI3Pb.cif")
         failure_reason = cif.check(structure)
         assert failure_reason is None
 
     def test_missing_elements(self):
         cif_str = ""
-        with open(f"{TEST_FILES_DIR}/MgNiF6.cif") as file:
+        with open(f"{TEST_FILES_DIR}/cif/MgNiF6.cif") as file:
             for line in file:
                 if "_chemical_formula_sum" in line:
                     # remove this line
@@ -892,7 +912,7 @@ Si1 Si 0 0 0 1 0.0
 
     def test_incorrect_stoichiometry(self):
         cif_str = ""
-        with open(f"{TEST_FILES_DIR}/MgNiF6.cif") as file:
+        with open(f"{TEST_FILES_DIR}/cif/MgNiF6.cif") as file:
             for line in file:
                 if "_chemical_formula_sum" in line:
                     line = line.replace("F6", "F5")
@@ -904,7 +924,7 @@ Si1 Si 0 0 0 1 0.0
         assert "Incorrect stoichiometry" in failure_reason
 
     def test_missing_cif_composition(self):
-        with open(f"{TEST_FILES_DIR}/LiFePO4.cif") as file:
+        with open(f"{TEST_FILES_DIR}/cif/LiFePO4.cif") as file:
             cif_str = file.read()
         # remove only key that gives info about CIF composition in this file
         cif_str = "\n".join([line for line in cif_str.split("\n") if "_atom_site_type_symbol" not in line])
@@ -913,11 +933,11 @@ Si1 Si 0 0 0 1 0.0
             file.write(cif_str)
 
         cif = CifParser(test_cif_file)
-        failure_reason = cif.check(Structure.from_file(f"{TEST_FILES_DIR}/LiFePO4.cif"))
+        failure_reason = cif.check(Structure.from_file(f"{TEST_FILES_DIR}/cif/LiFePO4.cif"))
         assert failure_reason == "Cannot determine chemical composition from CIF! 'NoneType' object is not iterable"
 
     def test_invalid_cif_composition(self):
-        with open(f"{TEST_FILES_DIR}/LiFePO4.cif") as file:
+        with open(f"{TEST_FILES_DIR}/cif/LiFePO4.cif") as file:
             cif_str = file.read()
 
         test_cif_file = f"{self.tmp_path}/test_broken.cif"
@@ -926,13 +946,21 @@ Si1 Si 0 0 0 1 0.0
             file.write(cif_str.replace("Li", "X"))
 
         cif = CifParser(test_cif_file)
-        failure_reason = cif.check(Structure.from_file(f"{TEST_FILES_DIR}/LiFePO4.cif"))
+        failure_reason = cif.check(Structure.from_file(f"{TEST_FILES_DIR}/cif/LiFePO4.cif"))
         assert failure_reason == "'X' is not a valid Element"
 
+    def test_skipping_relative_stoichiometry_check(self):
+        cif = CifParser(f"{TEST_FILES_DIR}/cif/Li10GeP2S12.cif")
+        struct = cif.parse_structures()[0]
+        failure_reason = cif.check(struct)
+        assert failure_reason is None
+        assert len(cif.warnings) == 2
+        assert cif.warnings[-1] == "Skipping relative stoichiometry check because CIF does not contain formula keys."
+
     def test_cif_writer_site_properties(self):
         # check CifWriter(write_site_properties=True) adds Structure site properties to
         # CIF with _atom_site_ prefix
-        struct = Structure.from_file(f"{TEST_FILES_DIR}/POSCAR")
+        struct = Structure.from_file(f"{VASP_IN_DIR}/POSCAR")
         struct.add_site_property(label := "hello", [1.0] * (len(struct) - 1) + [-1.0])
         out_path = f"{self.tmp_path}/test2.cif"
         CifWriter(struct, write_site_properties=True).write_file(out_path)
@@ -945,11 +973,11 @@ Si1 Si 0 0 0 1 0.0
 
 class TestMagCif(PymatgenTest):
     def setUp(self):
-        self.mcif = CifParser(f"{TEST_FILES_DIR}/magnetic.example.NiO.mcif")
-        self.mcif_ncl = CifParser(f"{TEST_FILES_DIR}/magnetic.ncl.example.GdB4.mcif")
-        self.mcif_incommensurate = CifParser(f"{TEST_FILES_DIR}/magnetic.incommensurate.example.Cr.mcif")
-        self.mcif_disordered = CifParser(f"{TEST_FILES_DIR}/magnetic.disordered.example.CuMnO2.mcif")
-        self.mcif_ncl2 = CifParser(f"{TEST_FILES_DIR}/Mn3Ge_IR2.mcif")
+        self.mcif = CifParser(f"{MCIF_TEST_DIR}/magnetic.example.NiO.mcif")
+        self.mcif_ncl = CifParser(f"{MCIF_TEST_DIR}/magnetic.ncl.example.GdB4.mcif")
+        self.mcif_incommensurate = CifParser(f"{MCIF_TEST_DIR}/magnetic.incommensurate.example.Cr.mcif")
+        self.mcif_disordered = CifParser(f"{MCIF_TEST_DIR}/magnetic.disordered.example.CuMnO2.mcif")
+        self.mcif_ncl2 = CifParser(f"{MCIF_TEST_DIR}/Mn3Ge_IR2.mcif")
 
     def test_mcif_detection(self):
         assert self.mcif.feature_flags["magcif"]
@@ -1015,12 +1043,12 @@ Gd1 5.05 5.05 0.0"""
         assert s_ncl.matches(s_ncl_from_msg)
 
     def test_write(self):
-        with open(f"{TEST_FILES_DIR}/GdB4-writer-ref.mcif") as file:
-            cw_ref_string = file.read()
+        with open(f"{MCIF_TEST_DIR}/GdB4-writer-ref.mcif") as file:
+            cw_ref_str = file.read()
         s_ncl = self.mcif_ncl.parse_structures(primitive=False)[0]
 
         cw = CifWriter(s_ncl, write_magmoms=True)
-        assert str(cw) == cw_ref_string
+        assert str(cw) == cw_ref_str
 
         # from list-type magmoms
         list_magmoms = [list(m) for m in s_ncl.site_properties["magmom"]]
@@ -1030,15 +1058,15 @@ Gd1 5.05 5.05 0.0"""
 
         s_ncl.add_site_property("magmom", list_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
-        assert str(cw) == cw_ref_string
+        assert str(cw) == cw_ref_str
 
         s_ncl.add_site_property("magmom", float_magmoms)
         cw = CifWriter(s_ncl, write_magmoms=True)
 
-        with open(f"{TEST_FILES_DIR}/GdB4-str-magnitudes-ref.mcif") as file:
-            cw_ref_string_magnitudes = file.read()
+        with open(f"{MCIF_TEST_DIR}/GdB4-str-magnitudes-ref.mcif") as file:
+            cw_ref_str_magnitudes = file.read()
 
-        assert str(cw).strip() == cw_ref_string_magnitudes.strip()
+        assert str(cw).strip() == cw_ref_str_magnitudes.strip()
         # test we're getting correct magmoms in ncl case
         s_ncl2 = self.mcif_ncl2.parse_structures()[0]
         list_magmoms = [list(m) for m in s_ncl2.site_properties["magmom"]]
@@ -1053,13 +1081,13 @@ Gd1 5.05 5.05 0.0"""
         cw = CifWriter(s_manual, write_magmoms=True)
 
         # check oxidation state
-        with open(f"{TEST_FILES_DIR}/CsCl-manual-oxi-ref.mcif") as file:
+        with open(f"{MCIF_TEST_DIR}/CsCl-manual-oxi-ref.mcif") as file:
             cw_manual_oxi_string = file.read()
         s_manual.add_oxidation_state_by_site([1, 1])
         cw = CifWriter(s_manual, write_magmoms=True)
         assert str(cw) == cw_manual_oxi_string
 
-    @unittest.skipIf(pybtex is None, "pybtex not present")
+    @pytest.mark.skipif(pybtex is None, reason="pybtex not present")
     def test_bibtex(self):
         ref_bibtex_string = """@article{cifref0,
     author = "Blanco, J.A.",
@@ -1070,3 +1098,26 @@ Gd1 5.05 5.05 0.0"""
 }
 """
         assert self.mcif_ncl.get_bibtex_string() == ref_bibtex_string
+
+
+def test_cif_writer_non_unique_labels(capsys):
+    # https://github.com/materialsproject/pymatgen/issues/3761
+    parser = CifParser(f"{TEST_FILES_DIR}/cif/garnet.cif")
+    struct = parser.parse_structures()[0]
+
+    assert struct.labels[:3] == ["Ca1", "Ca1", "Ca1"]
+    assert len(set(struct.labels)) != len(struct.labels)
+
+    # This should raise a warning
+    with pytest.warns(UserWarning, match="Site labels are not unique, which is not compliant with the CIF spec"):
+        CifWriter(struct)
+
+    struct.relabel_sites()
+    assert struct.labels[:3] == ["Ca1_1", "Ca1_2", "Ca1_3"]
+
+    _ = capsys.readouterr()
+    # This should not raise a warning
+    CifWriter(struct)
+    stdout, stderr = capsys.readouterr()
+    assert stdout == ""
+    assert stderr == ""
